<?php 
/* 
 ----------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2010 by the INDEPNET Development Team.
 
 http://indepnet.net/   http://glpi-project.org
 ----------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ------------------------------------------------------------------------
 */
//sl_SI

$LANG=array();


$LANG['backup'][0]="SQL Dump"; 
$LANG['backup'][1]="XML Dump"; 
$LANG['backup'][11]="Velikost"; 
$LANG['backup'][13]="Pogled/Prenos"; 
$LANG['backup'][16]="Ali ste prepričani da želite prepisati bazo z to datoteko:"; 
$LANG['backup'][17]="Ali ste prepričani da želite izbrisati to datoteko?"; 
$LANG['backup'][18]="Ali ste prepričani da želite shraniti bazo?"; 
$LANG['backup'][19]="Zdaj"; 
$LANG['backup'][21]="Datoteka že obstaja"; 
$LANG['backup'][22]="Ne morem najti bajta."; 
$LANG['backup'][23]="Mysql napaka, ki se začne iz"; 
$LANG['backup'][24]="Samodejno preusmerjanje, drugače kliknite"; 

$LANG['bookmark'][1]="zaznamek"; 
$LANG['bookmark'][2]="Partial load of the bookmark."; 
$LANG['bookmark'][3]="Niste še shranili nobenega zaznamka."; 
$LANG['bookmark'][4]="Nov zaznamek"; 
$LANG['bookmark'][5]="Javni zaznamki"; 
$LANG['bookmark'][6]="Potrdi privzeto"; 

$LANG['buttons'][0]="Išči"; 
$LANG['buttons'][2]="Objavi"; 
$LANG['buttons'][3]="Associate"; 
$LANG['buttons'][4]="Namesti"; 
$LANG['buttons'][5]="Odstrani"; 
$LANG['buttons'][6]="Izbriši"; 
$LANG['buttons'][7]="Posodobi"; 
$LANG['buttons'][8]="Dodaj"; 
$LANG['buttons'][9]="Poveži"; 
$LANG['buttons'][10]="Prekini"; 
$LANG['buttons'][11]="Naprej"; 
$LANG['buttons'][12]="Prejšnji"; 
$LANG['buttons'][13]="Nazaj"; 
$LANG['buttons'][14]="Posodobi"; 
$LANG['buttons'][15]="Razpored"; 
$LANG['buttons'][16]="Počisti"; 
$LANG['buttons'][17]="Obrni selekcijo"; 
$LANG['buttons'][18]="Označi vse"; 
$LANG['buttons'][19]="Odznači vse"; 
$LANG['buttons'][20]="Premakni"; 
$LANG['buttons'][21]="Obnovi"; 
$LANG['buttons'][22]="Purge"; 
$LANG['buttons'][23]="Pokaži"; 
$LANG['buttons'][24]="Pojdi navzgor"; 
$LANG['buttons'][25]="Pojdi navzdol"; 
$LANG['buttons'][27]="Current page in PDF"; 
$LANG['buttons'][28]="Current page in SLK"; 
$LANG['buttons'][29]="All pages in PDF"; 
$LANG['buttons'][30]="All pages in SLK"; 
$LANG['buttons'][31]="Izvozi"; 
$LANG['buttons'][32]="Končaj"; 
$LANG['buttons'][33]="Začni"; 
$LANG['buttons'][34]="Prekliči"; 
$LANG['buttons'][37]="Uvozi"; 
$LANG['buttons'][38]="Odkleni"; 
$LANG['buttons'][39]="Zamenjaj"; 
$LANG['buttons'][40]="Pokaži vse"; 
$LANG['buttons'][41]="Aktiviraj"; 
$LANG['buttons'][42]="Deaktiviraj"; 
$LANG['buttons'][43]="Razišči"; 
$LANG['buttons'][44]="Current page in CSV"; 
$LANG['buttons'][45]="All pages in CSV"; 
$LANG['buttons'][46]="Prej"; 
$LANG['buttons'][47]="Kasneje"; 
$LANG['buttons'][48]="Prenesi"; 
$LANG['buttons'][49]="Ohrani"; 
$LANG['buttons'][50]="Testiraj"; 
$LANG['buttons'][51]="Shrani"; 
$LANG['buttons'][52]="Naloži"; 
$LANG['buttons'][53]="Počisti"; 
$LANG['buttons'][55]="Prvi"; 
$LANG['buttons'][56]="Zadnji"; 
$LANG['buttons'][57]="Izvršiti"; 
$LANG['buttons'][58]="Posodobi"; 
$LANG['buttons'][59]="Pretrgati"; 

$LANG['calendar'][0]="YYYY-MM-DD"; 
$LANG['calendar'][1]="DD-MM-YYYY"; 
$LANG['calendar'][2]="MM-DD-YYYY"; 

$LANG['calendarD'][0]="N"; 
$LANG['calendarD'][1]="P"; 
$LANG['calendarD'][2]="T"; 
$LANG['calendarD'][3]="S"; 
$LANG['calendarD'][4]="Č"; 
$LANG['calendarD'][5]="P"; 
$LANG['calendarD'][6]="S"; 

$LANG['calendarDay'][0]="Nedelja"; 
$LANG['calendarDay'][1]="Ponedeljek"; 
$LANG['calendarDay'][2]="Torek"; 
$LANG['calendarDay'][3]="Sreda"; 
$LANG['calendarDay'][4]="Četrtek"; 
$LANG['calendarDay'][5]="Petek"; 
$LANG['calendarDay'][6]="Sobota"; 

$LANG['calendarM'][0]="Januar"; 
$LANG['calendarM'][1]="Februar"; 
$LANG['calendarM'][2]="Marec"; 
$LANG['calendarM'][3]="April"; 
$LANG['calendarM'][4]="Maj"; 
$LANG['calendarM'][5]="Junij"; 
$LANG['calendarM'][6]="Julij"; 
$LANG['calendarM'][7]="Avgust"; 
$LANG['calendarM'][8]="September"; 
$LANG['calendarM'][9]="Oktober"; 
$LANG['calendarM'][10]="November"; 
$LANG['calendarM'][11]="December"; 

$LANG['cartridges'][0]="Kartuša"; 
$LANG['cartridges'][7]="Ni najdenih kartuš"; 
$LANG['cartridges'][9]="Ni kartuše"; 
$LANG['cartridges'][10]="Toner"; 
$LANG['cartridges'][11]="Ink-Jet"; 
$LANG['cartridges'][12]="Tip kartuše"; 
$LANG['cartridges'][13]="Nov"; 
$LANG['cartridges'][14]="Uporabljen"; 
$LANG['cartridges'][15]="Obrabljen"; 
$LANG['cartridges'][16]="Kartuša(e)"; 
$LANG['cartridges'][20]="Nov"; 
$LANG['cartridges'][21]="Uporabljen"; 
$LANG['cartridges'][22]="Obrabljen"; 
$LANG['cartridges'][24]="Dodano (nabavljeno)"; 
$LANG['cartridges'][27]="Na"; 
$LANG['cartridges'][29]="End of life"; 
$LANG['cartridges'][32]="Modeli kompatabilnih tiskalnikov"; 
$LANG['cartridges'][33]="Uporabljene kartuše"; 
$LANG['cartridges'][34]="Ni proste kartuše"; 
$LANG['cartridges'][35]="Uporabljene kartuše"; 
$LANG['cartridges'][37]="Trak"; 
$LANG['cartridges'][39]="Tiskalniški števec"; 
$LANG['cartridges'][40]="Povprečen čas zaloge"; 
$LANG['cartridges'][41]="Povprečen čas uporabnosti"; 
$LANG['cartridges'][42]="Povprečno število natisnjenih strani"; 

$LANG['central'][2]="Zadnji"; 
$LANG['central'][4]="Ni dogodka"; 
$LANG['central'][5]="Domov"; 
$LANG['central'][6]="Odjavi"; 
$LANG['central'][7]="Pomoč"; 
$LANG['central'][8]="Dodatki"; 
$LANG['central'][9]="Vaša naročila v teku"; 
$LANG['central'][10]="Nova naročila"; 
$LANG['central'][12]="Osebni pogled"; 
$LANG['central'][13]="Globalni pogled"; 
$LANG['central'][14]="Skupinski pogled"; 
$LANG['central'][18]="Tvoje opravilo bo zaprto"; 
$LANG['central'][19]="Tvoja opravila so veljavna"; 

$LANG['choice'][0]="Ne"; 
$LANG['choice'][1]="Da"; 

$LANG['common'][0]="Brez imena"; 
$LANG['common'][1]="Predmet"; 
$LANG['common'][2]="ID"; 
$LANG['common'][3]="Show the trash"; 
$LANG['common'][4]="Splet"; 
$LANG['common'][5]="Proizvajalec"; 
$LANG['common'][6]="Ime predloge"; 
$LANG['common'][7]="Izberi predlogo"; 
$LANG['common'][8]="Upravljaj predloge..."; 
$LANG['common'][9]="Dodaj predlogo..."; 
$LANG['common'][10]="Odgovorni tehnik"; 
$LANG['common'][11]="Omejen pogled"; 
$LANG['common'][12]="Nastavitve"; 
$LANG['common'][13]="Predloga"; 
$LANG['common'][14]="Predloge"; 
$LANG['common'][15]="Lokacija"; 
$LANG['common'][16]="Ime"; 
$LANG['common'][17]="Tip"; 
$LANG['common'][18]="Alternate username"; 
$LANG['common'][19]="Serijska številka"; 
$LANG['common'][20]="Inventarna številka"; 
$LANG['common'][21]="Alternate username number"; 
$LANG['common'][22]="Model"; 
$LANG['common'][23]="Operacija uspešna"; 
$LANG['common'][24]="Ni izbranih elementov ali slabo definirana operacija"; 
$LANG['common'][25]="Komentarji"; 
$LANG['common'][26]="Zadnja nadgradnja"; 
$LANG['common'][27]="Datum"; 
$LANG['common'][28]="Izbrisano"; 
$LANG['common'][29]="Vtičniki"; 
$LANG['common'][30]="Nov predmet"; 
$LANG['common'][31]="Prazna predloga"; 
$LANG['common'][32]="Značilnosti"; 
$LANG['common'][33]="Skupaj"; 
$LANG['common'][34]="Uporabnik"; 
$LANG['common'][35]="Skupina"; 
$LANG['common'][36]="Kategorija"; 
$LANG['common'][37]="Writer"; 
$LANG['common'][38]="Use unitary management"; 
$LANG['common'][39]="Podvoji element tolikokrat kot je povezav"; 
$LANG['common'][40]="Do you really want to use unitary management this item ?"; 
$LANG['common'][41]="Email opozorila"; 
$LANG['common'][42]="Mobile phone"; 
$LANG['common'][43]="Ime"; 
$LANG['common'][44]="Privzeta vrednost(i)"; 
$LANG['common'][45]="MB maksimalno"; 
$LANG['common'][46]="Vcard"; 
$LANG['common'][47]="Napredek"; 
$LANG['common'][48]="Priimek"; 
$LANG['common'][49]="Nobeden"; 
$LANG['common'][50]="Confirm the final deletion ?"; 
$LANG['common'][51]="Celotno ime"; 
$LANG['common'][52]="Server"; 
$LANG['common'][53]="Seznam"; 
$LANG['common'][54]="Predmeta ni mogoče najti"; 
$LANG['common'][55]="Ste prepričani da žalite izbrisati ta element?"; 
$LANG['common'][56]="Standard interface"; 
$LANG['common'][57]="Naslov"; 
$LANG['common'][58]="Maksimalna vrednost"; 
$LANG['common'][59]="Globalno"; 
$LANG['common'][60]="Aktiven"; 
$LANG['common'][61]="Neznana napaka"; 
$LANG['common'][62]="Ostalo"; 
$LANG['common'][63]="Napaka"; 
$LANG['common'][64]="Upravitelj"; 
$LANG['common'][65]="Vmesnik"; 
$LANG['common'][66]="Vse"; 
$LANG['common'][67]="Ostali"; 
$LANG['common'][68]="ležeče"; 
$LANG['common'][69]="pokončno"; 
$LANG['common'][70]="Predmet uspešno dodan"; 
$LANG['common'][71]="Predmet uspešno posodobljen"; 
$LANG['common'][72]="Item successfully deleted"; 
$LANG['common'][73]="Item successfully purged"; 
$LANG['common'][74]="Predmet uspešno obnovljen"; 
$LANG['common'][75]="Ni pravice, da se ta predmet naredi rekurziven v tej entiteti"; 
$LANG['common'][76]="Javno"; 
$LANG['common'][77]="Zasebno"; 
$LANG['common'][78]="Nastavi javno"; 
$LANG['common'][79]="Set personal"; 
$LANG['common'][80]="Med nalaganjem..."; 
$LANG['common'][81]="Ne prikaži izbrisane elemente"; 
$LANG['common'][82]="MB"; 
$LANG['common'][83]="You don't have permission to perform this action."; 
$LANG['common'][84]="Sprememba zastavice prepovedana. Povezane predmete našel."; 
$LANG['common'][85]="Spremeni vidljivost v otrokovih entitetah"; 
$LANG['common'][86]="You are not allowed to change the visibility flag for child entities."; 
$LANG['common'][87]="Nova kartica"; 
$LANG['common'][88]="Osebno"; 
$LANG['common'][89]="Ni inštaliran"; 
$LANG['common'][90]="Objekt"; 
$LANG['common'][91]="Ne morem spremeniti atributa. Podedovan je od staršev."; 
$LANG['common'][92]="Drugo uporabniško ime"; 
$LANG['common'][93]="Nova glava otroka"; 

$LANG['computers'][0]="Nosilec"; 
$LANG['computers'][1]="Odstotek praznega prostora"; 
$LANG['computers'][2]="Velikost praznega prostora"; 
$LANG['computers'][3]="Globalna velikost"; 
$LANG['computers'][4]="Datotečni sistem"; 
$LANG['computers'][5]="Mount point"; 
$LANG['computers'][6]="Partition"; 
$LANG['computers'][7]="Dodaj nosilec"; 
$LANG['computers'][8]="Nosilci"; 
$LANG['computers'][9]="Operating system"; 
$LANG['computers'][10]="Serial of the operating system"; 
$LANG['computers'][11]="Product ID of the operating system"; 
$LANG['computers'][14]="Vstavljeno"; 
$LANG['computers'][23]="Type of memory"; 
$LANG['computers'][24]="Memory (MB)"; 
$LANG['computers'][25]="Hard drive size"; 
$LANG['computers'][36]="Hard drive type"; 
$LANG['computers'][37]="Monitor ni priključen"; 
$LANG['computers'][38]="Tiskalni ni priključen"; 
$LANG['computers'][39]="Tiskalnik"; 
$LANG['computers'][40]="Monitor(ji)"; 
$LANG['computers'][46]="Naprave"; 
$LANG['computers'][47]="Ni priključenih naprav"; 
$LANG['computers'][48]="Lokacija posodobljena. Povezani predmeti so bili prestavljeni v isto lokacijo."; 
$LANG['computers'][49]="Alternate username updated. The connected items have been updated using this alternate username."; 
$LANG['computers'][50]="Uporabnik in skupina sta posodobljeni. Povezani predmeti so bili prestavljeni v enake vrednosti."; 
$LANG['computers'][51]="Vir posodobitve"; 
$LANG['computers'][52]="Version of the operating system"; 
$LANG['computers'][53]="Servisni paket"; 
$LANG['computers'][54]="Telefon ni priključen"; 
$LANG['computers'][55]="Telefon"; 
$LANG['computers'][56]="Status posodobljen. Povezani predmeti so bili posodobljeni z uporabo tega statusa."; 

$LANG['connect'][0]="Direktne povezave"; 
$LANG['connect'][1]="Ni povezano."; 
$LANG['connect'][15]="Avtomatična posodobitev naslednjih predmetov"; 
$LANG['connect'][16]="Pozor!! Naslednja predmeta teh dveh naprav se ne ujemata"; 

$LANG['consumables'][0]="Potrošno blago"; 
$LANG['consumables'][1]="V zalogi"; 
$LANG['consumables'][2]="Reference"; 
$LANG['consumables'][7]="Nisem našel nobenega potrošnega blaga"; 
$LANG['consumables'][9]="Ni potrošnega blaga"; 
$LANG['consumables'][12]="Tip potrošnega blaga"; 
$LANG['consumables'][13]="Nov"; 
$LANG['consumables'][15]="Uporabljen"; 
$LANG['consumables'][16]="Potrošno blago"; 
$LANG['consumables'][20]="Nov"; 
$LANG['consumables'][22]="Uporabljen"; 
$LANG['consumables'][23]="Stanje"; 
$LANG['consumables'][26]="Uporabjeno (izdano)"; 
$LANG['consumables'][32]="Daj-dodeli"; 
$LANG['consumables'][35]="Used consumables"; 
$LANG['consumables'][36]="Lokacija zaloge"; 
$LANG['consumables'][37]="Vrni na zalogo"; 
$LANG['consumables'][38]="Alert threshold"; 

$LANG['contract'][0]="Pogodba poteče od"; 
$LANG['contract'][1]="Pogodba z objavo od"; 

$LANG['crontask'][0]="Avtomatične akcije"; 
$LANG['crontask'][1]="Sinhronizeraj opremo od OCSNG"; 
$LANG['crontask'][2]="Pošlji alarme na osnovi tonerjev in kartuš"; 
$LANG['crontask'][3]="Pošlji alarme na osnovi potrošnega materiala"; 
$LANG['crontask'][4]="Pošlji alarme na osnovi pretečenih licenc"; 
$LANG['crontask'][5]="Pošlji alarme na osnovi pogodb"; 
$LANG['crontask'][6]="Pošlji alarme na osnovi finančnih informacij"; 
$LANG['crontask'][7]="Izbriši stare dnevnike (loge)"; 
$LANG['crontask'][8]="Optimizacija baze"; 
$LANG['crontask'][9]="Dobi e-naslovnike"; 
$LANG['crontask'][10]="Preveri MySQL repliko"; 
$LANG['crontask'][11]="Preveri za nove posodobitve"; 
$LANG['crontask'][12]="Izbriši pretečene seje"; 
$LANG['crontask'][13]="Izbriši zgenerirano grafiko"; 
$LANG['crontask'][14]="Avtomatično zaprtje opravil"; 
$LANG['crontask'][15]="Ne rešena opravila"; 
$LANG['crontask'][31]="Onemogočen"; 
$LANG['crontask'][32]="Koledar"; 
$LANG['crontask'][33]="Teči"; 
$LANG['crontask'][34]="GLPI"; 
$LANG['crontask'][35]="CLI"; 
$LANG['crontask'][36]="Delujoča metoda"; 
$LANG['crontask'][37]="Pogostost delovanja"; 
$LANG['crontask'][38]="Delujojoč periodo"; 
$LANG['crontask'][39]="Število e-pošte, ki jo moram dobiti"; 
$LANG['crontask'][40]="Zadnji tek"; 
$LANG['crontask'][41]="Naslednji tek"; 
$LANG['crontask'][42]="Takoj, ko bo mogoče"; 
$LANG['crontask'][43]="Nobeno akcija ni v teku"; 
$LANG['crontask'][44]="Akcija dokončana, delno procesirana"; 
$LANG['crontask'][45]="akcija dokončana, polno procesirana"; 
$LANG['crontask'][46]="Akcija dokončana, nič ni za narediti"; 
$LANG['crontask'][47]="Zadnja lista teka"; 
$LANG['crontask'][48]="Začni"; 
$LANG['crontask'][50]="Števec teka"; 
$LANG['crontask'][51]="Minimalen čas"; 
$LANG['crontask'][52]="Maksimalen čas"; 
$LANG['crontask'][53]="Povprečni čas"; 
$LANG['crontask'][55]="Minimalen števec"; 
$LANG['crontask'][56]="Maksimalen števec"; 
$LANG['crontask'][57]="Povprečni števec"; 
$LANG['crontask'][58]="Skupaj število"; 
$LANG['crontask'][59]="Povprečna hitrost"; 
$LANG['crontask'][60]="Sistemska ključavnica"; 
$LANG['crontask'][61]="Onemogočen vtičnik"; 
$LANG['crontask'][62]="Elementi"; 

$LANG['devices'][0]="Dodaj novo komponento"; 
$LANG['devices'][1]="Trdi disk"; 
$LANG['devices'][2]="Grafične kartice"; 
$LANG['devices'][3]="Omrežne kartice"; 
$LANG['devices'][4]="Procesor"; 
$LANG['devices'][5]="Matična plošča"; 
$LANG['devices'][6]="Memory"; 
$LANG['devices'][7]="Zvočna kartica"; 
$LANG['devices'][19]="Pogoni"; 
$LANG['devices'][20]="Kontrolerji"; 
$LANG['devices'][21]="Ostale komponente"; 
$LANG['devices'][22]="Ohišja"; 
$LANG['devices'][23]="Oskrba z elektriko"; 
$LANG['devices'][24]="privzeto"; 
$LANG['devices'][25]="Dodaj komponento"; 
$LANG['devices'][26]="Odstrani komponento"; 

$LANG['device_case'][0]="Velikost"; 

$LANG['device_control'][0]="RAID"; 

$LANG['device_drive'][0]="Sposobnost pisanja"; 
$LANG['device_drive'][1]="Hitrost"; 

$LANG['device_hdd'][0]="Rpm"; 
$LANG['device_hdd'][1]="Predpomnilnik"; 
$LANG['device_hdd'][4]="Kapaciteta"; 

$LANG['device_iface'][0]="Pretok"; 
$LANG['device_iface'][2]="Mac Naslov"; 

$LANG['device_moboard'][0]="Čipovje"; 

$LANG['device_power'][0]="Energija"; 
$LANG['device_power'][1]="ATX"; 

$LANG['device_ram'][1]="Frekvenca"; 
$LANG['device_ram'][2]="Velikost"; 

$LANG['document'][1]="Kontrolna vsota(SHA1)"; 
$LANG['document'][2]="Datoteka"; 
$LANG['document'][3]=""; 
$LANG['document'][4]="MIME Tip"; 
$LANG['document'][7]="Tip dokumenta"; 
$LANG['document'][9]="Končnica"; 
$LANG['document'][10]="Ikona"; 
$LANG['document'][11]="Pooblaščen prenos"; 
$LANG['document'][15]="Prenesi"; 
$LANG['document'][16]="Dodaj dokument"; 
$LANG['document'][18]="Dokument"; 
$LANG['document'][19]="Povezani predmeti"; 
$LANG['document'][21]="Povezani dokumenti"; 
$LANG['document'][22]="Trenutna datoteka"; 
$LANG['document'][23]="File too large to be added."; 
$LANG['document'][24]="Datoteka je bila uspešno izbrisana"; 
$LANG['document'][25]="Napaka pri brisanju datoteke"; 
$LANG['document'][26]="Datoteka je pravilna. Upload je bil uspešen."; 
$LANG['document'][27]="Možen napad z nalaganjem ali pa je datoteka prevelika. Premikanje začasne datoteke je spodletelo."; 
$LANG['document'][28]="No file specified."; 
$LANG['document'][29]="Napaka pri ustvarjanju direktorija"; 
$LANG['document'][30]="Preverite če imate pravilna dovoljenja"; 
$LANG['document'][31]="Direktorij za dokumente ne obstaja"; 
$LANG['document'][32]="Neavtoriziran tip datoteke"; 
$LANG['document'][33]="Spletna povezava"; 
$LANG['document'][34]="Ustvari direktorij"; 
$LANG['document'][35]="Imenik za nalaganje ne obstaja"; 
$LANG['document'][36]="Uporabi FTP namestitveno datoteko"; 
$LANG['document'][37]="Nobena datoteka ni na voljo"; 
$LANG['document'][38]="Datoteka ni bila najdena"; 
$LANG['document'][39]="Dokument je bil uspešno premaknjen"; 
$LANG['document'][40]="Napaka pri premiku datoteke"; 
$LANG['document'][41]="Kopiranje dokumenta je uspelo"; 
$LANG['document'][42]="Dodano od"; 
$LANG['document'][43]="Neznana datoteka"; 
$LANG['document'][44]="Nepravilno ime datoteke"; 
$LANG['document'][45]="Neavtoriziran dostop do te datoteke"; 
$LANG['document'][46]="Napaka pri pošiljanju datoteke (definitivno je prevelika)"; 
$LANG['document'][48]="Dokument že obstaja s to datoteko"; 
$LANG['document'][49]="Datoteka je spremenjena (slaba kontrolna vsota)"; 
$LANG['document'][50]="Pripeti elementi"; 

$LANG['entity'][0]="Entiteta"; 
$LANG['entity'][2]="Root entiteta"; 
$LANG['entity'][3]="Poveži na entiteto"; 
$LANG['entity'][5]="Automatic computer assignment"; 
$LANG['entity'][6]="Samodejna dodelitev uporabnikov"; 
$LANG['entity'][7]="Drevesna struktura"; 
$LANG['entity'][8]="Po entiteti"; 
$LANG['entity'][9]="Podrejene entitete"; 
$LANG['entity'][10]="Izberite željeno entiteto"; 
$LANG['entity'][11]="da vidiš entito in njene pod entitete"; 
$LANG['entity'][12]="LDAP attribute identifying entity"; 
$LANG['entity'][13]="TAG identifying entity"; 
$LANG['entity'][14]="Napredne informacije"; 
$LANG['entity'][15]="Entitete LDAP direktorija"; 
$LANG['entity'][16]="Iskalni filter (če je potreben)"; 
$LANG['entity'][17]="Avtomatično zaprtje konfiguracij"; 
$LANG['entity'][18]="Avtomatično zaprtje opravil po"; 

$LANG['event'][0]="Source"; 
$LANG['event'][2]="Storitev"; 
$LANG['event'][3]="Stopnja"; 
$LANG['event'][4]="Sporočilo"; 
$LANG['event'][18]="Polje"; 
$LANG['event'][19]="Posodobitev"; 
$LANG['event'][20]="Ni zgodovinsko"; 

$LANG['financial'][1]="Pogodba"; 
$LANG['financial'][2]="Ima življenje"; 
$LANG['financial'][3]="Finančne informacije"; 
$LANG['financial'][4]="Številka"; 
$LANG['financial'][5]="Cena"; 
$LANG['financial'][6]="Tip pogodbe"; 
$LANG['financial'][8]="Trajanje"; 
$LANG['financial'][9]="Leto(a)"; 
$LANG['financial'][10]="Opozorilo"; 
$LANG['financial'][11]="Obdobje fakture"; 
$LANG['financial'][13]="Številka računa"; 
$LANG['financial'][14]="Datum nakupa"; 
$LANG['financial'][15]="Warranty duration"; 
$LANG['financial'][16]="Garancijske informacije"; 
$LANG['financial'][18]="Številka naročila"; 
$LANG['financial'][19]="Obrazec za pošiljanje"; 
$LANG['financial'][20]="Imobilizacijska številka"; 
$LANG['financial'][21]="Vrednost"; 
$LANG['financial'][22]="Amortizacijski tip"; 
$LANG['financial'][23]="Amortizacijska doba"; 
$LANG['financial'][24]="Dodaj osebo..."; 
$LANG['financial'][25]="Dodaj dobavitelja..."; 
$LANG['financial'][26]="Dobavitelj"; 
$LANG['financial'][30]="Faks"; 
$LANG['financial'][33]="Dodaj osebo"; 
$LANG['financial'][36]="Dodaj pogodbo"; 
$LANG['financial'][42]="Komercialen"; 
$LANG['financial'][43]="Tehnik"; 
$LANG['financial'][44]="Naslov"; 
$LANG['financial'][45]="Spletna stran"; 
$LANG['financial'][46]="Povezani kontakti"; 
$LANG['financial'][47]="Linearen"; 
$LANG['financial'][48]="Upadanje"; 
$LANG['financial'][50]="Posojilo"; 
$LANG['financial'][51]="Najem"; 
$LANG['financial'][52]="Najemni posli"; 
$LANG['financial'][53]="Zavarovanje"; 
$LANG['financial'][54]="Hardware podpora"; 
$LANG['financial'][55]="Software podpora"; 
$LANG['financial'][56]="Zagotovljena storitev - service"; 
$LANG['financial'][57]="Mesec"; 
$LANG['financial'][59]="Ure podpore"; 
$LANG['financial'][60]="na teden"; 
$LANG['financial'][61]="v Soboto"; 
$LANG['financial'][62]="Nedelje in prazniki"; 
$LANG['financial'][65]="Povezani dobavitelji"; 
$LANG['financial'][66]="Povezane pogodbe"; 
$LANG['financial'][68]="Aktiviraj finančne informacije"; 
$LANG['financial'][69]="Pogodbeni čas"; 
$LANG['financial'][76]="Začetni datum"; 
$LANG['financial'][77]="Amortizacijski koeficient"; 
$LANG['financial'][78]="Vrednost poteka garancije"; 
$LANG['financial'][79]="Third party Type"; 
$LANG['financial'][80]="Datum poteka garancije"; 
$LANG['financial'][81]="Računovodska neto vrednost"; 
$LANG['financial'][82]="Številka fakture"; 
$LANG['financial'][83]="Max number of items"; 
$LANG['financial'][84]="Za ta tip artikla, finančna informacija je le model za elemente za katere bi jih moral dodati."; 
$LANG['financial'][85]="Zahtevanega predmeta ni bilo mogoče najti"; 
$LANG['financial'][86]="Konec pogodbe"; 
$LANG['financial'][87]="Proračun"; 
$LANG['financial'][88]="Veljavno do:"; 
$LANG['financial'][89]="TCO (vrednost + stroški sledenja)"; 
$LANG['financial'][90]="Mesečni TCO"; 
$LANG['financial'][91]="TCO"; 
$LANG['financial'][92]="ANV"; 
$LANG['financial'][93]="Potekle pogodbe - zadnjih 30 dni"; 
$LANG['financial'][94]="Pogodbe, ki bodo potekle v manj kot 7 dneh"; 
$LANG['financial'][95]="Pogodbe, ki bodo potekle v manj kot 30 dneh"; 
$LANG['financial'][96]="Pogodbe kjer se odpovedi začnejo v manj kot v 7 dnevih'"; 
$LANG['financial'][97]="Pogodbe kjer se odpovedi začnejo v manj kot 30 dnevih"; 
$LANG['financial'][98]="Potek roka"; 
$LANG['financial'][99]="Datum poteka roka + Opomin"; 
$LANG['financial'][100]="Poštna številka"; 
$LANG['financial'][101]="Mesto"; 
$LANG['financial'][102]="State (Država?)"; 
$LANG['financial'][103]="Država"; 
$LANG['financial'][104]="Povezani predmeti"; 
$LANG['financial'][105]="Tiha privolitev"; 
$LANG['financial'][106]="Ekspresno"; 
$LANG['financial'][107]="Obnovitev"; 
$LANG['financial'][108]="Skupaj porabljeno iz proračuna"; 
$LANG['financial'][109]="Skupaj ostane še proračuna"; 
$LANG['financial'][110]="Proračun"; 

$LANG['gmt'][0]="GMT"; 
$LANG['gmt'][1]="Ura(e)"; 
$LANG['gmt'][2]="h"; 

$LANG['help'][1]="Matrika kalkulacij prioritete"; 
$LANG['help'][2]="Večji"; 
$LANG['help'][3]="Zelo visok"; 
$LANG['help'][4]="Visok"; 
$LANG['help'][5]="Srednje"; 
$LANG['help'][6]="Nizko"; 
$LANG['help'][7]="Zelo nizek"; 
$LANG['help'][8]="Obvesti me o izvedeni akciji"; 
$LANG['help'][11]="Moj E-mail"; 
$LANG['help'][14]="Oddaj sporočilo"; 
$LANG['help'][16]="If you want be notified about the action(s) taken, please enter your e-mail address."; 
$LANG['help'][18]="Vaše sporočilo je bilo uspešno poslano, vaša zahteva je v datoteki."; 
$LANG['help'][19]="Hvala za uporabo našega avtomatskega sistema za pomoč."; 
$LANG['help'][22]="Poišči ID vašega računalnika"; 
$LANG['help'][23]="Enter the first letters (user, item name, serial or asset number)"; 
$LANG['help'][24]="Tip strojne opreme"; 
$LANG['help'][25]="Računalnik"; 
$LANG['help'][26]="Omrezna naprava"; 
$LANG['help'][27]="Tiskalnik"; 
$LANG['help'][28]="Monitor"; 
$LANG['help'][29]="Naprava"; 
$LANG['help'][30]="Splošno"; 
$LANG['help'][31]="Software"; 
$LANG['help'][35]="Telefon"; 
$LANG['help'][40]="Ni naslova za vaše naročilo, prosim vnesite naslov."; 
$LANG['help'][41]="Ni kategorije v naročilu, prosim vnesite kategorijo"; 
$LANG['help'][42]="Zelo visoko"; 
$LANG['help'][43]="Visoko"; 
$LANG['help'][44]="Srednje"; 
$LANG['help'][45]="Nizko"; 
$LANG['help'][46]="Zelo nizko"; 
$LANG['help'][47]="Zelo visoko"; 
$LANG['help'][48]="Visoko"; 
$LANG['help'][49]="Srednje"; 
$LANG['help'][50]="Nizko"; 
$LANG['help'][51]="Zelo nizko"; 

$LANG['install'][0]="Namestitev ali posodobitev GLPI"; 
$LANG['install'][1]="Izberite 'Install' za popolnoma novo namestitev GLPI (podatki, ki bodo uvoženi z GLPI bodo privzeti podatki)"; 
$LANG['install'][2]="Izberite 'Posodobi' za posodobitev GLPI iz prejšnje verzije"; 
$LANG['install'][3]="Namestitev"; 
$LANG['install'][4]="Posodobitev"; 
$LANG['install'][5]="Preverjam kompatibilnost tvojega okolja z izvrševanjem GLPI"; 
$LANG['install'][6]="Test dokončan"; 
$LANG['install'][7]="Rezultati"; 
$LANG['install'][8]="Testiranje PHP razčlenjevalnika kode"; 
$LANG['install'][9]="Morate namestiti PHP5. Lahko ga prenesete tukaj :"; 
$LANG['install'][10]="GLPI ni kompatibilen z opcijo zend.ze1_compatibility_mode = On."; 
$LANG['install'][11]="PHP verzija je najmanj 5.x - Odlično !"; 
$LANG['install'][12]="Test sej"; 
$LANG['install'][13]="Vaš PHP razčlenjevalnik kode ni bil preveden s podporo za to sejo!"; 
$LANG['install'][14]="Podpora sejam je na voljo - Odlično !"; 
$LANG['install'][15]="Prepričajte se, da je podpora sejam aktivirana v vaši php.ini datoteki"; 
$LANG['install'][16]="Preverjam dovoljenje zapisanja za začasne datoteke"; 
$LANG['install'][17]="Datoteke ni bilo mogoče ustvariti."; 
$LANG['install'][18]="Neuradni prevodi so tudi na voljo"; 
$LANG['install'][19]="Datoteka je bila ustvarjena, vendar je ni mogoče izbrisati."; 
$LANG['install'][20]="Datoteka in direktorij sta bila ustvarjena in izbrisana - Odlično !"; 
$LANG['install'][21]="Preverjanje pravic pisanja za dokumentne datoteke"; 
$LANG['install'][22]="Datoteka je bila ustvarjena - Perfektno!"; 
$LANG['install'][23]="Preverjanje pravic pisanja za nastavitvene datoteke"; 
$LANG['install'][24]="Inicializacija baze"; 
$LANG['install'][25]="Nadaljuj ?"; 
$LANG['install'][26]="Nadaljuj"; 
$LANG['install'][27]="Poizkusite ponovno"; 
$LANG['install'][28]="Nastavitev povezave z bazo"; 
$LANG['install'][29]="Bazno povezovalni parametri"; 
$LANG['install'][30]="Mysql strežnik"; 
$LANG['install'][31]="Mysql uporabnik"; 
$LANG['install'][32]="Mysql geslo"; 
$LANG['install'][34]="Preverjanje povezave pri bazi"; 
$LANG['install'][35]="Ne morem se povezati z bazo"; 
$LANG['install'][36]="Strežnik je odgovoril"; 
$LANG['install'][37]="Server in/ali uporabniško polje sta prazna"; 
$LANG['install'][38]="Prosim izberite bazo:"; 
$LANG['install'][39]="Ustvari novo bazo ali uporabi že obstoječo"; 
$LANG['install'][40]="Prosim izberite bazo za posodobitev:"; 
$LANG['install'][41]="Nemogoče je uporabiti bazo:"; 
$LANG['install'][43]="OK - baza je bila inicializirana"; 
$LANG['install'][47]="Nemogoče je pisati v namestitveno datoteko baze"; 
$LANG['install'][48]="Napaka pri ustvarjanju baze !"; 
$LANG['install'][49]="Niste izbrali baze !"; 
$LANG['install'][50]="Preverjanje pravic pisanja za datoteke sej"; 
$LANG['install'][52]="Check write permissions for automatic actions files"; 
$LANG['install'][53]="Testiraj pisanje log datotek"; 
$LANG['install'][55]="Namestitev je končana"; 
$LANG['install'][57]="Privzeta uporabniška imena / gesla so:"; 
$LANG['install'][58]="glpi/glpi za administracijski račun"; 
$LANG['install'][59]="tech/tech za tehničev račun"; 
$LANG['install'][60]="normal/normal for the normal account"; 
$LANG['install'][61]="post-only/postonly for the postonly account"; 
$LANG['install'][62]="You can delete or modify these accounts as well as the initial data."; 
$LANG['install'][64]="Uporabi GLPI"; 
$LANG['install'][65]="magic_quotes_sybase razširitveni test"; 
$LANG['install'][66]="GLPI ne deluje z magic_quotes_sybase izbiro ; Prosim, da jo izklopite in poizkusite ponovno"; 
$LANG['install'][67]="magic_quotes_sybase izbira ni aktivna na vašem strežniku - Odlično !"; 
$LANG['install'][68]="Testiraj sejo avto začetek"; 
$LANG['install'][69]="session.auto_start je aktivirana. Poglej .htaccess datoteko v GLPI korenu za več informacij."; 
$LANG['install'][70]="Ni mogoče ustvariti datoteke za povezavo z bazo. Preverite pravice na mape."; 
$LANG['install'][71]="Mysql razširitveni test."; 
$LANG['install'][72]="Vaš php morate prevesti z Mysql razširitvijo."; 
$LANG['install'][73]="Ok - funkcija mysql_query() obstaja - Odlično !"; 
$LANG['install'][74]="Preveri če je Session_use_trans_sid uporabljen"; 
$LANG['install'][75]="Prosim deaktivirajte Session_use_trans_id izbiro v php.ini datoteki"; 
$LANG['install'][76]="Ok - seja deluja (ni težav s trans_id) - Odlično !"; 
$LANG['install'][77]="Korak"; 
$LANG['install'][81]="Začetek namestitve"; 
$LANG['install'][82]="Baza je bila ustvarjena"; 
$LANG['install'][85]="Funkcionalnost je bila najdena - Odlično!"; 
$LANG['install'][86]="Test dodeljenosti pomnilnika"; 
$LANG['install'][87]="Dodeljen pomnilnik:"; 
$LANG['install'][88]="Za GLPI je ponavadi potrebno minimalno 64MB"; 
$LANG['install'][89]="Odlično !"; 
$LANG['install'][90]="Poizkusite povečati memory_limit parameter v php.ini datoteki."; 
$LANG['install'][91]="Dodeljen pomnilnik > 64M"; 
$LANG['install'][92]="Licenca"; 
$LANG['install'][93]="Sem prebral in se strinjam z pogoji pogodbe, ki so napisani zgoraj."; 
$LANG['install'][94]="Sem prebral in SE NE STRINJAM s pogoji pogodbe, ki so napisani zgoraj"; 
$LANG['install'][95]="Neskončen spomin"; 
$LANG['install'][96]="Neskončen spomin"; 
$LANG['install'][97]="Prepričajte se, da ima PHP pravice pisanja na imenik:"; 
$LANG['install'][99]="Preverjanje pravic pisanja za predpomnilniške datoteke"; 
$LANG['install'][100]="Imenika ni bilo mogoče ustvariti."; 
$LANG['install'][101]="Imenik je bil ustvarjen, vendar ga ni bilo mogoče odstraniti."; 
$LANG['install'][102]="Test json funkcije"; 
$LANG['install'][103]="GLPI ne more delati pravilno z json_encode in json_decode funkcijo"; 
$LANG['install'][104]="mbstring podaljšek test"; 
$LANG['install'][105]="Mbstring podaljšek za tvoj razčlenjevalnik PHP ni nameščen"; 
$LANG['install'][106]="Preveri dovoljenja za pisanje za grafične datoteke"; 

$LANG['job'][2]="od"; 
$LANG['job'][4]="Naročnik"; 
$LANG['job'][5]="Dodeljeno k"; 
$LANG['job'][6]="Tehnik"; 
$LANG['job'][7]="Naloga"; 
$LANG['job'][8]="last(s) ticket(s)"; 
$LANG['job'][9]="Sledi zgoraj"; 
$LANG['job'][11]="Opišite problem"; 
$LANG['job'][12]="Za to naročilo ni odgovorov."; 
$LANG['job'][13]="New ticket"; 
$LANG['job'][15]="Solved"; 
$LANG['job'][19]="Opombe po e-mailu"; 
$LANG['job'][20]="Skupaj trajanje"; 
$LANG['job'][21]="Ura(e)"; 
$LANG['job'][22]="Minuta(e)"; 
$LANG['job'][29]="Dodaj opombo"; 
$LANG['job'][30]="Dodaj novo nalogo"; 
$LANG['job'][31]="Trajanje"; 
$LANG['job'][32]="Nobeden"; 
$LANG['job'][33]="Izprazni opis"; 
$LANG['job'][34]="Plan this task"; 
$LANG['job'][35]="Načrtovanje"; 
$LANG['job'][37]="Povzetek"; 
$LANG['job'][38]="Naročilo"; 
$LANG['job'][39]="Popravi follow-up"; 
$LANG['job'][40]="Časovni stroški"; 
$LANG['job'][41]="Fiksna cena"; 
$LANG['job'][42]="Cena materiala"; 
$LANG['job'][43]="Skupna cena"; 
$LANG['job'][44]="Vir naročila"; 
$LANG['job'][45]="Vir sledi"; 
$LANG['job'][46]="The ticket will be added in the entity"; 
$LANG['job'][47]="Stroški"; 
$LANG['job'][48]="Tip rešitve"; 
$LANG['job'][49]="Nova naloga"; 
$LANG['job'][50]="Nobena naloga ni za to opravilo"; 
$LANG['job'][51]="Odobritev rešitve"; 
$LANG['job'][52]="Posodobitev naloge"; 
$LANG['job'][53]="Izbris naloge"; 
$LANG['job'][54]="Brez odgovora, opravilo bo avtomatično zaprto po"; 

$LANG['joblist'][0]="Status"; 
$LANG['joblist'][1]="Le moji"; 
$LANG['joblist'][2]="Prioriteta"; 
$LANG['joblist'][3]="Osebno + skupin(e)"; 
$LANG['joblist'][4]="Dodeljen"; 
$LANG['joblist'][6]="Opis"; 
$LANG['joblist'][7]="Novo naročilo za ta predmet..."; 
$LANG['joblist'][8]="Ni naročil"; 
$LANG['joblist'][9]="Nov"; 
$LANG['joblist'][10]="Zaprto (Rešeno)"; 
$LANG['joblist'][11]="Odprto"; 
$LANG['joblist'][12]="Closed on"; 
$LANG['joblist'][13]="Opravila, ki bodo procesirana"; 
$LANG['joblist'][14]="Rešeno na"; 
$LANG['joblist'][16]="Nobeno naročilo ni v teku."; 
$LANG['joblist'][17]="Zaprto (ni rešeno)"; 
$LANG['joblist'][18]="V teku (dodeljeno)"; 
$LANG['joblist'][19]="V teku (načrtovano)"; 
$LANG['joblist'][21]="V obdelavi"; 
$LANG['joblist'][26]="V teku"; 
$LANG['joblist'][27]="E-mail naslov za opombe"; 
$LANG['joblist'][28]="Opravila na povezanih elementih"; 
$LANG['joblist'][29]="Nujno"; 
$LANG['joblist'][30]="Vpliv"; 
$LANG['joblist'][32]="Rešeno"; 
$LANG['joblist'][33]="Zaprta"; 
$LANG['joblist'][34]="Ni rešeno"; 
$LANG['joblist'][35]="Ni zaprto"; 
$LANG['joblist'][36]="Vrednost statusa v bazi"; 

$LANG['jobresolution'][1]="Rešitev"; 
$LANG['jobresolution'][3]="Odobrena rešitev"; 
$LANG['jobresolution'][4]="Zavrnjena rešitev"; 
$LANG['jobresolution'][5]="Če zavrneš to rešitev, moraš navesti razlog"; 

$LANG['knowbase'][1]="FAQ"; 
$LANG['knowbase'][5]="Put this item in the FAQ"; 
$LANG['knowbase'][6]="Izberi kategorijo za ta predmet :"; 
$LANG['knowbase'][7]="Delete this item from the FAQ"; 
$LANG['knowbase'][8]="Uredi ta predmet"; 
$LANG['knowbase'][9]="Izbriši ta predmet"; 
$LANG['knowbase'][10]="This item is part of the FAQ"; 
$LANG['knowbase'][11]="This item is not part of the FAQ"; 
$LANG['knowbase'][12]="Root"; 
$LANG['knowbase'][13]="Ime kategorije"; 
$LANG['knowbase'][14]="Zadeva"; 
$LANG['knowbase'][15]="Vsebina"; 
$LANG['knowbase'][24]="Dostop do pogosto zastavljenih vprašanj"; 
$LANG['knowbase'][26]="Pogledi"; 
$LANG['knowbase'][27]="On"; 
$LANG['knowbase'][29]="Nedavni vnosi"; 
$LANG['knowbase'][30]="Najbolj pogosta vprašanja"; 

$LANG['ldap'][0]="Bulk import users from a LDAP directory"; 
$LANG['ldap'][1]="Sinhronizacija že uvoženih uporabnikov"; 
$LANG['ldap'][2]="Uvoz novih uporabnikov"; 
$LANG['ldap'][3]="Ni uporabnikov za uvoz"; 
$LANG['ldap'][4]="LDAP izbira imenika"; 
$LANG['ldap'][5]="Prosim izberite LDAP imenik iz katerega se bo uvozilo uporabnike"; 
$LANG['ldap'][6]="Ni se mogoče povezati z LDAP imenikom"; 
$LANG['ldap'][7]="Noben LDAP imenik ni definiran v GLPI"; 
$LANG['ldap'][8]="Pozor: Prošnja je presegla mejo direktorija. Rezultat je le delni."; 
$LANG['ldap'][9]="Test povezave do LDAP imenika"; 
$LANG['ldap'][12]="Sinhronizacija"; 
$LANG['ldap'][13]="in the LDAP directory"; 
$LANG['ldap'][14]="v GLPI"; 
$LANG['ldap'][15]="Sinhroniziraj"; 
$LANG['ldap'][16]="Prekonfiguracija"; 
$LANG['ldap'][17]="Aktivni imenik"; 
$LANG['ldap'][18]="List of LDAP directory replicates"; 
$LANG['ldap'][19]="Kopiraj"; 
$LANG['ldap'][20]="Add a LDAP directory replica"; 
$LANG['ldap'][21]="Glavni strežnik"; 
$LANG['ldap'][22]="Repliciraj"; 
$LANG['ldap'][23]="Bulk import groups from a LDAP directory"; 
$LANG['ldap'][24]="Uvoz novih skupin"; 
$LANG['ldap'][25]="Ni skupine za uvoz"; 
$LANG['ldap'][30]="Kako LDAP z drugim imenom bo narejeno"; 
$LANG['ldap'][31]="Nikoli ne dereferenciraj (privzeto)"; 
$LANG['ldap'][32]="Vedno dereferenciraj"; 
$LANG['ldap'][33]="Dereferenciraj med iskanjem (toda ne med lociranjem)"; 
$LANG['ldap'][34]="Dereferancija ko lociraš (ne med iskanjem)"; 
$LANG['ldap'][35]="Uvozi uporabnika"; 
$LANG['ldap'][36]="Noben direktorij ni povezan z entiteto : išče nemogoče"; 
$LANG['ldap'][38]="Išči kriterije za uporabnike"; 
$LANG['ldap'][39]="Napredno"; 
$LANG['ldap'][40]="Enostavno"; 
$LANG['ldap'][41]="Spremeni"; 
$LANG['ldap'][42]="Noben direktorij ni izbran"; 
$LANG['ldap'][43]="Noben uporabnik ni sinhronizeran"; 
$LANG['ldap'][44]="Privzeti strežnik"; 
$LANG['ldap'][45]="Akcija, ko je uporabnik izbrisan iz LDAP imenika"; 
$LANG['ldap'][46]="Umakni akreditacije in skupine (dinamično)"; 
$LANG['ldap'][47]="Daj v smeti"; 
$LANG['ldap'][48]="Izbriši uporabnika iz LDAP direktorija"; 
$LANG['ldap'][49]="Poglej uporabnike dodane od"; 
$LANG['ldap'][50]="Poglej uporabnike posodobljene od"; 
$LANG['ldap'][52]="Manj kot"; 
$LANG['ldap'][53]="Več kot"; 
$LANG['ldap'][54]="Omogoči razvrščanje po datumu"; 
$LANG['ldap'][55]="Onemogoči razvrščanje po datumu"; 
$LANG['ldap'][56]="Tedni"; 

$LANG['links'][1]="Povezava ali ime datoteke"; 
$LANG['links'][4]="Povezan tip strojne opreme"; 
$LANG['links'][6]="Valid tags"; 
$LANG['links'][7]="Ni definirane nobene povezave"; 
$LANG['links'][9]="Vsebina datoteke"; 

$LANG['log'][1]="sistem"; 
$LANG['log'][16]="Načrtovanje"; 
$LANG['log'][18]="komponente"; 
$LANG['log'][20]="predmet dodan"; 
$LANG['log'][21]="posodobi predmet"; 
$LANG['log'][22]="izbriši predmet"; 
$LANG['log'][23]="obnovi predmet"; 
$LANG['log'][24]="dokončno izbriši napravo"; 
$LANG['log'][26]="Prekini povezavo z predmetom"; 
$LANG['log'][27]="povezava predmeta"; 
$LANG['log'][28]="modifikacija komponent"; 
$LANG['log'][29]="Odobritev/odklonitev rešitve"; 
$LANG['log'][30]="Povezan tip"; 
$LANG['log'][31]="izbriši tip"; 
$LANG['log'][32]="add a link with an item"; 
$LANG['log'][33]="Izbriši povezavo s predmetom"; 
$LANG['log'][34]="Dodaj povezavo z dobaviteljem"; 
$LANG['log'][35]="Izbriši povezavo z dobaviteljem"; 
$LANG['log'][40]="IP povezava"; 
$LANG['log'][41]="povezava ni uspela"; 
$LANG['log'][42]="Rezervacija"; 
$LANG['log'][44]="Naslov"; 
$LANG['log'][45]="Uspešno"; 
$LANG['log'][46]="Neuspešno"; 
$LANG['log'][48]="Dodaj uporabnika v skupino"; 
$LANG['log'][49]="izbriši uporabnika iz skupine"; 
$LANG['log'][55]="Povezava"; 
$LANG['log'][59]="Automatic action"; 
$LANG['log'][60]="use unitary management for this item"; 
$LANG['log'][61]="Dodaj uporabnika k entiteti"; 
$LANG['log'][62]="popolnoma odstrani uporabnika"; 
$LANG['log'][64]="modifikacija polja"; 
$LANG['log'][65]="pravilo"; 
$LANG['log'][66]="Varnost"; 
$LANG['log'][67]="modifikacija zapiskov"; 
$LANG['log'][70]="omrežni port dodan"; 
$LANG['log'][71]="dodanih več omrežnih vrat"; 
$LANG['log'][73]="omrežni port izbrisan"; 
$LANG['log'][74]="izbrisanih več omrežnih vrat"; 
$LANG['log'][75]="omrežni port premaknjen"; 
$LANG['log'][77]="associate a VLAN to a network port"; 
$LANG['log'][78]="associate a VLAN to several ports"; 
$LANG['log'][79]="vlan dissociated from a network port"; 
$LANG['log'][80]="dissociation of a VLAN from multiple network ports"; 
$LANG['log'][82]="Dodajanje verzije"; 
$LANG['log'][83]="modifikacija verzije"; 
$LANG['log'][84]="Verzija izbrisa"; 
$LANG['log'][85]="Dodajanje licence"; 
$LANG['log'][86]="modifikacija licence"; 
$LANG['log'][87]="Izbris licence"; 
$LANG['log'][88]="dodaj kartuše"; 
$LANG['log'][89]="dodaj potrošni material"; 
$LANG['log'][90]="izključitev kartuše"; 
$LANG['log'][91]="izključitev consumable"; 
$LANG['log'][92]="Obnova kartuše"; 
$LANG['log'][93]="Restavriranje consumable"; 
$LANG['log'][94]="popravi kartušo"; 
$LANG['log'][95]="inštaliraj kartušo"; 
$LANG['log'][96]="odstrani kartušo"; 
$LANG['log'][97]="consumable ni več za uporabnika"; 
$LANG['log'][98]="dodaj element"; 
$LANG['log'][99]="modifikacija elementa"; 
$LANG['log'][100]="izbris elementa"; 

$LANG['login'][0]="Nazadnje prijavljen/a"; 
$LANG['login'][1]="Ponovno se prijavite"; 
$LANG['login'][2]="LDAP directory"; 
$LANG['login'][3]="IMAP/POP"; 
$LANG['login'][4]="CAS"; 
$LANG['login'][5]="Dostop zavrnjen"; 
$LANG['login'][6]="Uporabniško ime"; 
$LANG['login'][7]="Geslo"; 
$LANG['login'][8]="Prazno uporabniško ime ali geslo"; 
$LANG['login'][9]="Ni še overjeno"; 
$LANG['login'][10]="Prijava"; 
$LANG['login'][11]="Uporabnik ni pooblaščen za povezavo v GLPI"; 
$LANG['login'][12]="Nepravilno uporabniško ime ali geslo"; 
$LANG['login'][13]="Polje za geslo je prazno"; 
$LANG['login'][14]="neznan uporabnik"; 
$LANG['login'][15]="Uporabnika ne najdem ali več najdenih uporabnikov"; 
$LANG['login'][16]="Neuspešna avtentikacija v LDAP"; 
$LANG['login'][18]="Baza notranja GLPI"; 
$LANG['login'][20]="Nimate dostopa do aplikacije, ker je vaš račun bil deaktiviran in odstranjen"; 
$LANG['login'][21]="Testiraj povezavo do IMAP/POP strežnika"; 
$LANG['login'][22]="Test uspešen"; 
$LANG['login'][23]="Test neuspešen"; 
$LANG['login'][24]="Zadnji datum prijave"; 
$LANG['login'][25]="Nimate pravic za povezavo"; 
$LANG['login'][26]="Aktivirati morate JavaScript funkcijo v vašem brskalniku"; 
$LANG['login'][27]="Morate sprejeti piškotke, da lahko pridete do aplikacije"; 
$LANG['login'][30]="Sprememba avtentikacijske metode"; 
$LANG['login'][31]="Authentication on a LDAP directory"; 
$LANG['login'][32]="Avtentikacija na GLPI bazo"; 
$LANG['login'][33]="Avtentikacija na IMAP/POP strežnik"; 

$LANG['mailgate'][0]="Prejemnik pošte"; 
$LANG['mailgate'][2]="Dobi poštne naslove naročil sedaj"; 
$LANG['mailgate'][3]="Število dosegljivih in vrnjenih e-mailov"; 
$LANG['mailgate'][4]="mbstring dodatka nisem našel. Opozorilo nabor znakov uporabljenih."; 
$LANG['mailgate'][5]="Pripeta datoteka je nepravilna"; 
$LANG['mailgate'][6]="Pripeta datoteka je prevelika"; 
$LANG['mailgate'][7]="Maximum size of each file imported by the mail receiver"; 
$LANG['mailgate'][9]="Tvoj e-pošta ni bila procesirana. \nČe problem ostaja, kontaktiraj administratorja"; 
$LANG['mailgate'][10]="E-pošta zavrnjena"; 
$LANG['mailgate'][11]="Procesiraj uvoz e-pošte"; 
$LANG['mailgate'][12]="Ne more vplivati na poštno entiteto"; 
$LANG['mailgate'][13]="Razlog za odklanjanje"; 
$LANG['mailgate'][14]="E-pošta ni bila najdena. Ne mogoče uvoziti"; 
$LANG['mailgate'][16]="Odgovori:"; 

$LANG['mailing'][0]="----------------------------------------------------------"; 
$LANG['mailing'][1]="======================================================================"; 
$LANG['mailing'][4]="Already done followup(s)"; 
$LANG['mailing'][5]="Opis naročila"; 
$LANG['mailing'][10]="Nov odgovor naročila"; 
$LANG['mailing'][12]="naročilo dodeljeno k"; 
$LANG['mailing'][14]="Posodobi kategorijo naročila"; 
$LANG['mailing'][15]="Posodobi prioriteto naročila"; 
$LANG['mailing'][17]="Posodobitev zadeve naročila"; 
$LANG['mailing'][18]="Posodobitev avtorja naročila"; 
$LANG['mailing'][19]="Nova rezervacija"; 
$LANG['mailing'][20]="Posodobitev skupine naročila"; 
$LANG['mailing'][21]="Spremeni v izvornem naročilu"; 
$LANG['mailing'][23]="Sprememba rezervacije"; 
$LANG['mailing'][26]="Dodan dokument :"; 
$LANG['mailing'][27]="Posodobitev statusa naročila"; 
$LANG['mailing'][29]="Rezervacija je ukinjena"; 
$LANG['mailing'][30]="Posodobitev naročila"; 
$LANG['mailing'][31]="To je testni email, da se preveri če sistem pravilno deluje"; 
$LANG['mailing'][32]="Mail Test"; 
$LANG['mailing'][33]="Opozorilo za kartuše"; 
$LANG['mailing'][35]="Najvišja ali najnižja stopnja alarma dosežena za tip consumable:"; 
$LANG['mailing'][36]="Opozorilo za potrošni material"; 
$LANG['mailing'][37]="Pogodba vnešena v objavljenem času"; 
$LANG['mailing'][39]="Pogodbeno opozorilo"; 
$LANG['mailing'][40]="Predmet je prispel na konec garancije:"; 
$LANG['mailing'][41]="Alarm finančnih informacij"; 
$LANG['mailing'][42]="Spremeni urne stroške"; 
$LANG['mailing'][43]="Spremeni fiksne stroške"; 
$LANG['mailing'][44]="Spremeni materialne stroške"; 
$LANG['mailing'][45]="Spremeni naslov naročila"; 
$LANG['mailing'][46]="Spremeni opis naročila"; 
$LANG['mailing'][47]="Napaka pri pošiljanju emaila"; 
$LANG['mailing'][48]="Spremeni čas odprtja"; 
$LANG['mailing'][49]="Spremeni čas zaprtja"; 
$LANG['mailing'][50]="Spremeni prejemnika naročila"; 
$LANG['mailing'][51]="Potekla licenca :"; 
$LANG['mailing'][53]="Spremeni razrešitev"; 
$LANG['mailing'][54]="Datum prenehanja"; 
$LANG['mailing'][100]="Brez definirane kategorije"; 
$LANG['mailing'][101]="Pošta je bila omogočena"; 
$LANG['mailing'][102]="Pošta je bila onemogočena"; 
$LANG['mailing'][104]="Sledi trajanju"; 
$LANG['mailing'][105]="Ni dodeljeno"; 
$LANG['mailing'][107]="Nič"; 
$LANG['mailing'][109]="Brez skupine"; 
$LANG['mailing'][110]="Nepravilen Email"; 
$LANG['mailing'][113]="Objave predlog"; 
$LANG['mailing'][114]="Telo"; 
$LANG['mailing'][115]="Glavni del e-naslova"; 
$LANG['mailing'][116]="HTML"; 
$LANG['mailing'][117]="besedilo"; 
$LANG['mailing'][118]="E-naslov"; 
$LANG['mailing'][119]="Ponavljajoč"; 
$LANG['mailing'][120]="Objava metode"; 
$LANG['mailing'][121]="Prejemniki"; 
$LANG['mailing'][122]="Naloge, ki so že narejene"; 
$LANG['mailing'][123]="Rešeno opravilo"; 
$LANG['mailing'][124]="Dodaj novi prevod"; 
$LANG['mailing'][125]="Privzeti prevod"; 
$LANG['mailing'][126]="Predloga za prevod"; 
$LANG['mailing'][127]="Zapri opravilo"; 
$LANG['mailing'][128]="pusti polje prazno za generacijo iz HTMLja"; 
$LANG['mailing'][129]="Izbris opravila"; 
$LANG['mailing'][130]="Od"; 
$LANG['mailing'][131]="Prejemnik"; 
$LANG['mailing'][132]="Glava pošte"; 
$LANG['mailing'][133]="Izbriši e-sporočila"; 
$LANG['mailing'][134]="Posodobi kar sledi"; 
$LANG['mailing'][135]="Sledi izbrisu"; 
$LANG['mailing'][136]="Konec rezervacije"; 
$LANG['mailing'][137]="Strojna oprema uporabnika"; 
$LANG['mailing'][138]="Lista dosegljivih povezav"; 
$LANG['mailing'][139]="Nalepka"; 
$LANG['mailing'][140]="Povezava"; 
$LANG['mailing'][141]="Sledi"; 
$LANG['mailing'][142]="Naloge"; 
$LANG['mailing'][143]="Valideraj"; 
$LANG['mailing'][144]="Zgodovinsko"; 
$LANG['mailing'][145]="Lista vrednosti"; 
$LANG['mailing'][146]="Ena vrednost"; 
$LANG['mailing'][147]="Možne vrednosti"; 

$LANG['Menu'][0]="Računalniki"; 
$LANG['Menu'][1]="Omrežna oprema"; 
$LANG['Menu'][2]="Tiskalniki"; 
$LANG['Menu'][3]="Monitorji"; 
$LANG['Menu'][4]="Programska oprema"; 
$LANG['Menu'][5]="Tickets"; 
$LANG['Menu'][6]="Poročila"; 
$LANG['Menu'][11]="Nastavitve"; 
$LANG['Menu'][12]="Maintenance"; 
$LANG['Menu'][13]="Statistike"; 
$LANG['Menu'][14]="Uporabniki"; 
$LANG['Menu'][15]="Administracija"; 
$LANG['Menu'][16]="Naprave"; 
$LANG['Menu'][17]="Rezervacije"; 
$LANG['Menu'][18]="Orodja"; 
$LANG['Menu'][19]="Knowledge base"; 
$LANG['Menu'][20]="FAQ"; 
$LANG['Menu'][21]="Kartuše"; 
$LANG['Menu'][22]="Kontakti"; 
$LANG['Menu'][23]="Dobavitelji"; 
$LANG['Menu'][24]="Finančne informacije"; 
$LANG['Menu'][25]="Pogodbe"; 
$LANG['Menu'][26]="Upravljanje"; 
$LANG['Menu'][27]="Dokumenti"; 
$LANG['Menu'][28]="Status"; 
$LANG['Menu'][29]="Načrtovanje"; 
$LANG['Menu'][30]="Dnevniki"; 
$LANG['Menu'][31]="Simplified interface"; 
$LANG['Menu'][32]="Potrošni m."; 
$LANG['Menu'][33]="OCSNG"; 
$LANG['Menu'][34]="Telefoni"; 
$LANG['Menu'][35]="Profili"; 
$LANG['Menu'][36]="Skupine"; 
$LANG['Menu'][37]="Entitete"; 
$LANG['Menu'][38]="Inventar"; 
$LANG['Menu'][39]="Prejemniki"; 
$LANG['Menu'][40]="Priljubljene"; 
$LANG['Menu'][41]="Pravice (rights)"; 

$LANG['monitors'][14]="Mikrofon"; 
$LANG['monitors'][15]="Zvočniki"; 
$LANG['monitors'][18]="Zastavice"; 
$LANG['monitors'][19]="Sub-D"; 
$LANG['monitors'][20]="BNC"; 
$LANG['monitors'][21]="Velikost"; 
$LANG['monitors'][32]="DVI"; 
$LANG['monitors'][33]="Pivot - zasuk"; 

$LANG['networking'][4]="Network vrata (Network port)"; 
$LANG['networking'][5]="Memory (MB)"; 
$LANG['networking'][6]="Omrežna vrata"; 
$LANG['networking'][13]="omrežna vrata najdena"; 
$LANG['networking'][14]="IP"; 
$LANG['networking'][15]="MAC"; 
$LANG['networking'][17]="Povezan na"; 
$LANG['networking'][19]="Dodaj omrežna vrata..."; 
$LANG['networking'][21]="Port number"; 
$LANG['networking'][25]="on"; 
$LANG['networking'][37]="networking port(s) found"; 
$LANG['networking'][44]="Vrata"; 
$LANG['networking'][46]="Dodaj več vrat..."; 
$LANG['networking'][47]="Od"; 
$LANG['networking'][48]="To"; 
$LANG['networking'][51]="Omrežna točka - network point"; 
$LANG['networking'][55]="Povezati v VLAN"; 
$LANG['networking'][56]="VLAN"; 
$LANG['networking'][57]="Izberi MAC naslov iz seznama ali pa specificiraj spodaj"; 
$LANG['networking'][58]="Dissociate a VLAN"; 
$LANG['networking'][59]="Prehod"; 
$LANG['networking'][60]="Maska"; 
$LANG['networking'][61]="Podomrežje - subnet"; 

$LANG['ocsconfig'][1]="OCSNG database user"; 
$LANG['ocsconfig'][2]="Host for the OCSNG database"; 
$LANG['ocsconfig'][3]="OCSNG user password"; 
$LANG['ocsconfig'][4]="Name of the OCSNG database"; 
$LANG['ocsconfig'][5]="Možnosti uvoza"; 
$LANG['ocsconfig'][6]="Ignore in OCSNG import"; 
$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
$LANG['ocsconfig'][9]="Izključi naslednje znake (ločilo $, nič za vse)"; 
$LANG['ocsconfig'][10]="Globalni uvoz"; 
$LANG['ocsconfig'][11]="Brez uvoza"; 
$LANG['ocsconfig'][12]="Uvoz enote"; 
$LANG['ocsconfig'][13]="Enota uvoza: vse kar je uvoženo kot 'as-is'"; 
$LANG['ocsconfig'][14]="Globalni uvoz: vse je uvoženo toda material je gloalno upravljen (brez dvojnih imen - blooms)"; 
$LANG['ocsconfig'][15]="Brez uvoza: vtičnik ne bo uvozil teh elementov"; 
$LANG['ocsconfig'][16]="Privzeti status"; 
$LANG['ocsconfig'][17]="Omeji uvoz k naslednjim znakom (ločilo $, nič za vse)"; 
$LANG['ocsconfig'][18]="Najprej preverite, če so podvojeni zapisi urejeni v OCSNG"; 
$LANG['ocsconfig'][19]="Uvoz enote po serijski številki"; 
$LANG['ocsconfig'][27]="Osnovne informacije"; 
$LANG['ocsconfig'][36]="Modemi"; 
$LANG['ocsconfig'][37]="Vrata"; 
$LANG['ocsconfig'][38]="Use the OCSNG software dictionary"; 
$LANG['ocsconfig'][39]="OCSNG TAG"; 
$LANG['ocsconfig'][40]="Number of items to synchronize via the automatic OCSNG action"; 
$LANG['ocsconfig'][41]="Register"; 
$LANG['ocsconfig'][43]="OCSNG Administrative Information"; 
$LANG['ocsconfig'][48]="Obnašanje pri prekinitvi"; 
$LANG['ocsconfig'][49]="Koš"; 
$LANG['ocsconfig'][50]="Brisanje"; 
$LANG['ocsconfig'][52]="Automatic connection of computers"; 
$LANG['ocsconfig'][53]="Enable the automatic link"; 
$LANG['ocsconfig'][54]="Existence criteria of a computer"; 
$LANG['ocsconfig'][55]="Find computers having the status"; 
$LANG['ocsconfig'][56]="izprazni"; 
$LANG['ocsconfig'][57]="enako"; 
$LANG['ocsconfig'][58]="The link automatically connects a GLPI computer with one in OCSNG.<br>This option is taken into account during manual link and by synchronization scripts."; 
$LANG['ocsconfig'][59]="Web address of the OCSNG console"; 

$LANG['ocsng'][0]="OCS Inventorij NG"; 
$LANG['ocsng'][1]="Sinhronizacija že uvoženih računalnikov"; 
$LANG['ocsng'][2]="Uvozi nove računalnike"; 
$LANG['ocsng'][3]="Clean links between GLPI and OCSNG"; 
$LANG['ocsng'][4]="Poveži nove OCS računalnike z že obstoječimi GLPI računalniki"; 
$LANG['ocsng'][5]="Uvozi nove računalnike"; 
$LANG['ocsng'][6]="Avtomatska posodobitev"; 
$LANG['ocsng'][7]="Uvoženo iz OCSNG"; 
$LANG['ocsng'][8]="Uvoz uspešen"; 
$LANG['ocsng'][9]="No new computer to be imported"; 
$LANG['ocsng'][10]="Computers updated in OCSNG"; 
$LANG['ocsng'][11]="Posodobi računalnike"; 
$LANG['ocsng'][12]="No new computer to be updated"; 
$LANG['ocsng'][13]="Uvozi podatke v GLPI"; 
$LANG['ocsng'][14]="Last OCSNG inventory date"; 
$LANG['ocsng'][15]="Ni polj ki bi bila zaklenjena"; 
$LANG['ocsng'][16]="Zaklenjena polja"; 
$LANG['ocsng'][18]="Connection to OCSNG database successful"; 
$LANG['ocsng'][19]="Valid OCSNG configuration and version"; 
$LANG['ocsng'][20]="Invalid OCSNG Version: RC3 is required"; 
$LANG['ocsng'][21]="Connection to the OCSNG database failed"; 
$LANG['ocsng'][22]="Pozor! Uvoženi podatki (poglejte v vaše nastavitve) bodo prepisali obstoječe podatke"; 
$LANG['ocsng'][23]="Unable to import, GLPI computer is already related to an element of OCSNG"; 
$LANG['ocsng'][24]="Vsili sinhronizacijo"; 
$LANG['ocsng'][26]="Choice of an OCSNG server"; 
$LANG['ocsng'][27]="No OCSNG server defined"; 
$LANG['ocsng'][29]="OCSNG server"; 
$LANG['ocsng'][30]="Zaklenjen(i) monitor(ji)"; 
$LANG['ocsng'][32]="Zaklenjena naprava(e)"; 
$LANG['ocsng'][34]="Zaklenjeni tiskalnik(i)"; 
$LANG['ocsng'][36]="Ciljna entiteta"; 
$LANG['ocsng'][37]="Aktivirajte predogled"; 
$LANG['ocsng'][38]="Onemogoči predogled"; 
$LANG['ocsng'][40]="Ujemanje s pravilom ?"; 
$LANG['ocsng'][41]="Ročni uvoz"; 
$LANG['ocsng'][42]="Invalid OCSNG configuration (TRACE_DELETED must be active)"; 
$LANG['ocsng'][43]="Access denied on OCSNG database (Need write rights on hardware.CHECKSUM necessary)"; 
$LANG['ocsng'][44]="Access denied on OCSNG database (Delete rights in deleted_equiv table necessary)"; 
$LANG['ocsng'][45]="OCS ID"; 
$LANG['ocsng'][46]="Deleted in OCSNG"; 
$LANG['ocsng'][47]="Linked with an OCSNG computer"; 
$LANG['ocsng'][48]="The OCSNG ID of the computer changed"; 
$LANG['ocsng'][49]="Agent"; 
$LANG['ocsng'][50]="Zaklenjen IP"; 
$LANG['ocsng'][52]="Zaklenjena programska oprema"; 
$LANG['ocsng'][54]="Software deleted by OCSNG synchronization"; 
$LANG['ocsng'][55]="Nosilci zaklenjeni"; 
$LANG['ocsng'][57]="OCSNG Interface"; 

$LANG['pager'][1]="do"; 
$LANG['pager'][2]="od"; 
$LANG['pager'][3]="od"; 
$LANG['pager'][4]="Pokaži"; 
$LANG['pager'][5]="Predmetov"; 

$LANG['peripherals'][18]="Znamka"; 
$LANG['peripherals'][31]="Globalno upravljanje"; 
$LANG['peripherals'][32]="Upravitelj enot"; 
$LANG['peripherals'][33]="Upravljalni tip"; 

$LANG['phones'][18]="Znamka"; 
$LANG['phones'][36]="Dovod energije"; 
$LANG['phones'][38]="Slušalke"; 
$LANG['phones'][39]="Zvočnik"; 
$LANG['phones'][40]="Šetvilo vrstic"; 

$LANG['planning'][0]="Zahtevani tehnik že ima planiran dogodek za ta čas"; 
$LANG['planning'][1]="Napaka pri vpisovanju datumov. Začetni datum je starejši kot končni datum"; 
$LANG['planning'][5]="Dan"; 
$LANG['planning'][6]="Teden"; 
$LANG['planning'][8]="Sledenje"; 
$LANG['planning'][9]="Po"; 
$LANG['planning'][10]="Ical"; 
$LANG['planning'][11]="Webcal"; 
$LANG['planning'][12]="Download the planning in Ical format"; 
$LANG['planning'][13]="webcal:// Synchronization"; 
$LANG['planning'][14]="Mesec"; 
$LANG['planning'][15]="Vaše načrtovanje"; 
$LANG['planning'][16]="Informacije"; 
$LANG['planning'][17]="narediti"; 
$LANG['planning'][18]="Končano"; 

$LANG['plugins'][0]="Seznam vtičnikov"; 
$LANG['plugins'][2]="Instaliran / ni konfiguriran"; 
$LANG['plugins'][3]="Instaliran / ni aktiviran"; 
$LANG['plugins'][4]="Napaka / izbriši"; 
$LANG['plugins'][5]="Ne obstoječa funkcija"; 
$LANG['plugins'][6]="Posodobi"; 
$LANG['plugins'][7]="Noben vtičnik ni nameščen"; 
$LANG['plugins'][8]="Poglej katalog vtičnikov"; 
$LANG['plugins'][9]="Avtorji"; 
$LANG['plugins'][10]="Incompatible plugin with this version of GLPI"; 

$LANG['printers'][14]="Serijska (zaporedna)"; 
$LANG['printers'][15]="Pararelna (vzporedna)"; 
$LANG['printers'][18]="Vrata"; 
$LANG['printers'][27]="USB"; 
$LANG['printers'][28]="Ethernet"; 
$LANG['printers'][29]="Brezžični (Wifi)"; 
$LANG['printers'][30]="Prvoten števec strani"; 
$LANG['printers'][31]="Natisnjene strani"; 

$LANG['profiles'][0]="Globalne pravice"; 
$LANG['profiles'][1]="Pravica entite"; 
$LANG['profiles'][2]="Profile's interface"; 
$LANG['profiles'][4]="Dodaj sledeča opravila iz mojih skupin"; 
$LANG['profiles'][5]="Ustvari naročilo"; 
$LANG['profiles'][6]="Add a followup to tickets (requester)"; 
$LANG['profiles'][7]="Pokaži vsa naročila"; 
$LANG['profiles'][8]="View all follow-ups and tasks (public and private)"; 
$LANG['profiles'][9]="Show public followups and tasks"; 
$LANG['profiles'][10]="Beri"; 
$LANG['profiles'][11]="Piši"; 
$LANG['profiles'][12]="Ni dostopa"; 
$LANG['profiles'][13]="Privzeti profil"; 
$LANG['profiles'][14]="Izbriši naročilo"; 
$LANG['profiles'][15]="Dodaj opombo vsem naročilom"; 
$LANG['profiles'][16]="Odgovoren bo za naročila"; 
$LANG['profiles'][17]="Ukradi naročilo"; 
$LANG['profiles'][18]="Posodobi naročilo"; 
$LANG['profiles'][19]="Dodeli naročilo"; 
$LANG['profiles'][20]="Poglej njegov plan"; 
$LANG['profiles'][21]="View all plannings"; 
$LANG['profiles'][22]="Profil"; 
$LANG['profiles'][23]="Administracija rezervacije"; 
$LANG['profiles'][24]="Posodobi geslo"; 
$LANG['profiles'][26]="Prikaži kreirana naročila mojih skupin"; 
$LANG['profiles'][27]="See hardware of my group(s)"; 
$LANG['profiles'][28]="Rekurziven"; 
$LANG['profiles'][29]="Dinamičen"; 
$LANG['profiles'][30]="Poglej OCSNG informacije"; 
$LANG['profiles'][31]="Ročno sinhroniziraj OCSNG"; 
$LANG['profiles'][32]="Poglej dodeljena naročila (osebne in skupinske asociacije)"; 
$LANG['profiles'][33]="Noben uporabnik osnovan"; 
$LANG['profiles'][34]="Napis"; 
$LANG['profiles'][35]="Popravi vse kar sledi"; 
$LANG['profiles'][36]="Poglej koledar ljudeh mojih skupin"; 
$LANG['profiles'][37]="Privzeta entiteta"; 
$LANG['profiles'][38]="Vidljivost"; 
$LANG['profiles'][39]="Dodelitev"; 
$LANG['profiles'][40]="Posodobi"; 
$LANG['profiles'][41]=""; 
$LANG['profiles'][42]="Asociacija"; 
$LANG['profiles'][43]="Avtentikacija in sinhronizacija uporabniških metod"; 
$LANG['profiles'][44]="Spremeni prioriteto"; 
$LANG['profiles'][45]="Dodaj naloge vsem opravilom"; 
$LANG['profiles'][46]="Spremeni vse naloge"; 
$LANG['profiles'][47]="Ddoaj uporabnike iz zunanjega vira"; 
$LANG['profiles'][48]="Skreiraj veljavno prošnjo"; 
$LANG['profiles'][49]="Potrdi prošnjo"; 

$LANG['registry'][1]="Skupen - hive"; 
$LANG['registry'][2]="Pot"; 
$LANG['registry'][3]="Ključ/vrednost"; 
$LANG['registry'][4]="Registerski ključ(i) najden"; 
$LANG['registry'][5]="Noben ključ ni bil najden v registru"; 
$LANG['registry'][6]="OCSNG name"; 

$LANG['reminder'][0]="Osebni zapiski"; 
$LANG['reminder'][1]="Javni zapiski"; 
$LANG['reminder'][6]="Nov zapisek"; 
$LANG['reminder'][9]="Tekst"; 
$LANG['reminder'][12]="Add to schedule"; 
$LANG['reminder'][15]="Brez naslova"; 
$LANG['reminder'][16]="Globalni zapiski"; 

$LANG['reports'][0]="Izberite poročilo ki ga želite generirati"; 
$LANG['reports'][4]="Seznam strojne opreme pod pogodbo"; 
$LANG['reports'][11]="Strojna oprema pod pogodbo"; 
$LANG['reports'][12]="Tip strojne opreme"; 
$LANG['reports'][13]="Datum(i)"; 
$LANG['reports'][15]="Pokaži poročilo"; 
$LANG['reports'][19]="Alternate username"; 
$LANG['reports'][26]="Privzeto poročilo"; 
$LANG['reports'][27]="Po pogodbi"; 
$LANG['reports'][28]="Po letu"; 
$LANG['reports'][33]="Omrežno poročilo"; 
$LANG['reports'][36]="Povezane naprave"; 
$LANG['reports'][37]="Vtičnice"; 
$LANG['reports'][38]="IP"; 
$LANG['reports'][39]="Po lokaciji"; 
$LANG['reports'][41]="Po računalniški strojni opremi - hardware"; 
$LANG['reports'][42]="Po menijih"; 
$LANG['reports'][46]="Porti računalniške strojne opreme"; 
$LANG['reports'][47]="vrata naprav"; 
$LANG['reports'][49]="Omrežno poročilo od strojne opreme - hardware"; 
$LANG['reports'][51]="Omrežno poročilo po meniju"; 
$LANG['reports'][52]="stikalo - switch"; 
$LANG['reports'][54]="Omrežno poročilo po lokaciji"; 
$LANG['reports'][57]="Seznam materiala"; 
$LANG['reports'][58]="Equipment's report by year"; 
$LANG['reports'][60]="Datum odpiranja"; 
$LANG['reports'][61]="Closing date"; 
$LANG['reports'][62]="Finančni podatki strojne opreme"; 
$LANG['reports'][63]="Ostali finančni podatki (licence, kartuše, consumables)"; 
$LANG['reports'][64]="Datum sklepa"; 

$LANG['reservation'][1]="Rezervirani predmeti"; 
$LANG['reservation'][2]="Naprave trenutno nedostopna"; 
$LANG['reservation'][3]="Make unavailable"; 
$LANG['reservation'][5]="Make available"; 
$LANG['reservation'][6]="Prohibit reservations"; 
$LANG['reservation'][7]="Authorize reservations"; 
$LANG['reservation'][8]="Knjiga"; 
$LANG['reservation'][9]="Knjiga predmetov"; 
$LANG['reservation'][16]="Za"; 
$LANG['reservation'][17]="Od"; 
$LANG['reservation'][18]="Potrebni predmet je že rezerviran za ta časovni okvir"; 
$LANG['reservation'][20]="Back to planning"; 
$LANG['reservation'][21]="See planning"; 
$LANG['reservation'][22]="Uredi komentar"; 
$LANG['reservation'][25]="All reservable hardware"; 
$LANG['reservation'][27]="Ponavljan"; 
$LANG['reservation'][28]="Po tednu"; 
$LANG['reservation'][29]="Po dnevu"; 
$LANG['reservation'][30]="times"; 
$LANG['reservation'][31]="po"; 
$LANG['reservation'][35]="Prihodnost in napredek Rezervacij"; 
$LANG['reservation'][36]="Pretekle rezervacije"; 
$LANG['reservation'][37]="Ni rezervacij"; 
$LANG['reservation'][38]="Are you sure you want do return this non-reservable item ?"; 
$LANG['reservation'][39]="To bo odstranilo vse rezervacije v teku."; 
$LANG['reservation'][40]="Rezervacije za material, ki potečejo danes"; 

$LANG['rulesengine'][0]="je"; 
$LANG['rulesengine'][1]="ni"; 
$LANG['rulesengine'][2]="vsebuje"; 
$LANG['rulesengine'][3]="ne vsebuje"; 
$LANG['rulesengine'][4]="začni z"; 
$LANG['rulesengine'][5]="finished by"; 
$LANG['rulesengine'][6]="Kriterij"; 
$LANG['rulesengine'][7]="Akcije"; 
$LANG['rulesengine'][8]="Upravljanje pravil"; 
$LANG['rulesengine'][9]="Ujemanje tipa (logical operator)"; 
$LANG['rulesengine'][10]="Pozicija"; 
$LANG['rulesengine'][11]="Tip akcije"; 
$LANG['rulesengine'][12]="Polja"; 
$LANG['rulesengine'][13]="Vrednost"; 
$LANG['rulesengine'][14]="Pogoj"; 
$LANG['rulesengine'][15]="Razlog"; 
$LANG['rulesengine'][16]="Kriterij"; 
$LANG['rulesengine'][17]="Pravila"; 
$LANG['rulesengine'][18]="Rules for assigning a computer to an entity"; 
$LANG['rulesengine'][19]="Entiteta in pravice za določanje pravil"; 
$LANG['rulesengine'][20]="Pravila, ki se vršijo"; 
$LANG['rulesengine'][21]="Pravila primerna v pod-entitetah"; 
$LANG['rulesengine'][22]="Dodeli"; 
$LANG['rulesengine'][23]="Lokalna pravila"; 
$LANG['rulesengine'][24]="Tip pravila"; 
$LANG['rulesengine'][25]="Computer's name"; 
$LANG['rulesengine'][26]="regular expression checks"; 
$LANG['rulesengine'][27]="regular expression does not match"; 
$LANG['rulesengine'][28]="Business rules for tickets"; 
$LANG['rulesengine'][29]="Seznam pravil"; 
$LANG['rulesengine'][30]="Akcija"; 
$LANG['rulesengine'][33]="Slovar spodnji"; 
$LANG['rulesengine'][35]="Slovar programja"; 
$LANG['rulesengine'][36]="Slovar izdelovalca"; 
$LANG['rulesengine'][37]="Pravila določanja kategorij programja"; 
$LANG['rulesengine'][38]="Izračunaj"; 
$LANG['rulesengine'][40]="kategorija"; 
$LANG['rulesengine'][41]="Validacija"; 
$LANG['rulesengine'][42]="AND"; 
$LANG['rulesengine'][43]="OR"; 
$LANG['rulesengine'][45]="Assign the value from regular expression"; 
$LANG['rulesengine'][46]="Prepuščen: oprema IP naslov"; 
$LANG['rulesengine'][47]="Prepuščen: ime opreme + domena"; 
$LANG['rulesengine'][48]="Odstopljena oprema"; 
$LANG['rulesengine'][49]="Prepuščen: opremin MAC naslov"; 
$LANG['rulesengine'][50]="Računalniški model slovarja"; 
$LANG['rulesengine'][51]="Slovar model monitorjev"; 
$LANG['rulesengine'][52]="Slovar telefonskega modela"; 
$LANG['rulesengine'][53]="Zunanja naprava model slovarjev"; 
$LANG['rulesengine'][54]="Slovar model tiskalnika"; 
$LANG['rulesengine'][55]="Slovar mrežnega modela"; 
$LANG['rulesengine'][56]="Modeli"; 
$LANG['rulesengine'][60]="Računalniški tip slovarja"; 
$LANG['rulesengine'][61]="Slovar tipa monitorjev"; 
$LANG['rulesengine'][62]="slovar tip telefona"; 
$LANG['rulesengine'][63]="Zunanja naprava tipi slovarjev"; 
$LANG['rulesengine'][64]="Slovar tip tiskalnika"; 
$LANG['rulesengine'][65]="Omrežna naprava tipi slovarjev"; 
$LANG['rulesengine'][66]="Tipi"; 
$LANG['rulesengine'][67]="Operating systems dictionary"; 
$LANG['rulesengine'][68]="Slovar servis paketa"; 
$LANG['rulesengine'][69]="OS slovar verzij"; 
$LANG['rulesengine'][70]="Pravila za določitev opravila skreirana skozi poštni prejemnik"; 
$LANG['rulesengine'][76]="Ponovi slovar"; 
$LANG['rulesengine'][77]="Slovarji"; 
$LANG['rulesengine'][78]="Verzija"; 
$LANG['rulesengine'][79]="Add the result from regular expression"; 
$LANG['rulesengine'][80]="Globalni slovar"; 
$LANG['rulesengine'][81]="Rezultat pravila"; 
$LANG['rulesengine'][82]="Podrobnosti rezultata"; 
$LANG['rulesengine'][83]="It is possible to affect the result of a regular expression using the string #0"; 
$LANG['rulesengine'][84]="Testiraj pravila motorja"; 
$LANG['rulesengine'][85]="Result of the regular expression"; 
$LANG['rulesengine'][86]="Softwarecategory affected when software deleted by dictionary"; 
$LANG['rulesengine'][87]="Programje izbrisan po GLPI slovarju"; 
$LANG['rulesengine'][90]="Delo v teku..."; 
$LANG['rulesengine'][91]="Delo končano."; 
$LANG['rulesengine'][92]="Opozorilo pred zagonom slovarja"; 
$LANG['rulesengine'][93]="Pozor ! Ta operacija lahko programsko opremo postavi v koš.<br>O tem obvestite vaše uporabnike!"; 
$LANG['rulesengine'][94]="FUSION"; 
$LANG['rulesengine'][95]="Izbira izdelovalca"; 
$LANG['rulesengine'][96]="Ponovi slovar za izdelovalca<br> ( ----- = All)"; 
$LANG['rulesengine'][97]="Ni elementov ki bi morali biti testirani"; 
$LANG['rulesengine'][100]="Informacija predpomnilnika"; 
$LANG['rulesengine'][102]="Ime pravila"; 
$LANG['rulesengine'][103]="Predmeti v predpomnilniku"; 
$LANG['rulesengine'][104]="Prvotna vrednost"; 
$LANG['rulesengine'][105]="Spremenjena vrednost"; 
$LANG['rulesengine'][106]="Nespremenjeno"; 
$LANG['rulesengine'][107]="Neaktiven"; 
$LANG['rulesengine'][108]="original"; 
$LANG['rulesengine'][110]="Pravice za določitev"; 
$LANG['rulesengine'][111]="Entitetne dodelitve"; 
$LANG['rulesengine'][112]="Pravice in entite nalog"; 
$LANG['rulesengine'][120]="Motor prekine na prvem preverjanju pravil."; 
$LANG['rulesengine'][121]="Motor upravlja s pravili."; 
$LANG['rulesengine'][122]="Motor vrne rezultate pravil k naslednjim."; 
$LANG['rulesengine'][130]="Entiteta od LDAP-a"; 
$LANG['rulesengine'][131]="Entiteta od TAG-a"; 
$LANG['rulesengine'][132]="Ne se zavedati uvoza"; 
$LANG['rulesengine'][133]="Eniteta od domene"; 
$LANG['rulesengine'][134]="Zavrni e-naslov (brez odgovora na e-naslov)"; 
$LANG['rulesengine'][135]="Zavrni e-naslov (z odgovorom na e-naslov)"; 
$LANG['rulesengine'][138]="LDAP kriteriji"; 
$LANG['rulesengine'][140]="Dodaj kriterij"; 
$LANG['rulesengine'][142]="Lista ne uvoženih e-naslovov"; 
$LANG['rulesengine'][144]="Entiteta na osnovi uporabnikovega profila"; 
$LANG['rulesengine'][145]="Uporabnik z enim samim profilom"; 
$LANG['rulesengine'][146]="Uporabnik z značilnostjo profila"; 
$LANG['rulesengine'][147]="Uporabnik z značilnostjo enega profila"; 
$LANG['rulesengine'][148]="Poštna domena je poznana"; 
$LANG['rulesengine'][150]="Pravila, ki vplivajo na entito so bila onemogočena."; 

$LANG['search'][0]="Iskanje"; 
$LANG['search'][1]="za vse"; 
$LANG['search'][2]="vsebuje"; 
$LANG['search'][4]="urejeno po"; 
$LANG['search'][8]="Datum začetka"; 
$LANG['search'][9]="Končni datum"; 
$LANG['search'][10]="v"; 
$LANG['search'][11]="Predmeti videni"; 
$LANG['search'][12]="Navedi konec datuma"; 
$LANG['search'][15]="Ni najdenih predmetov"; 
$LANG['search'][16]="Najmanj"; 
$LANG['search'][17]="Dodaj iskalni kriterij"; 
$LANG['search'][18]="Izbriši iskalni kriterij"; 
$LANG['search'][19]="Dodaj globalni iskalni kriterij"; 
$LANG['search'][20]="Izbriši globalni iskalni kriterij"; 

$LANG['setup'][0]="Padajoči seznami"; 
$LANG['setup'][2]="Dodaj uporabnika..."; 
$LANG['setup'][3]="LDAP directory link"; 
$LANG['setup'][4]="Tipi računalnikov"; 
$LANG['setup'][5]="Operacijski sistem"; 
$LANG['setup'][6]="Personalizacija"; 
$LANG['setup'][9]="Mrežni vmesniki"; 
$LANG['setup'][10]="Display order of surnames firstnames"; 
$LANG['setup'][14]="Email"; 
$LANG['setup'][18]="Prijava"; 
$LANG['setup'][19]="Geslo"; 
$LANG['setup'][20]="Potrdilo za geslo"; 
$LANG['setup'][21]="Napaka : oba gesla nista enaka"; 
$LANG['setup'][35]="MHz"; 
$LANG['setup'][39]="Sledi privatnemu za privzeto"; 
$LANG['setup'][40]="Privatna opravila po privzetem"; 
$LANG['setup'][41]="Izberite jezik"; 
$LANG['setup'][42]="Tipi omrežja"; 
$LANG['setup'][43]="Tip tiskalnika"; 
$LANG['setup'][44]="Tipi monitorjev"; 
$LANG['setup'][45]="Tip primera"; 
$LANG['setup'][46]="Privzeta vrednost"; 
$LANG['setup'][47]="Privzeta črka formata"; 
$LANG['setup'][48]="Privzete vrednosti"; 
$LANG['setup'][62]="Izberite kategorijo za konfiguracijo"; 
$LANG['setup'][63]="Pozor: izbrisali boste naslov, ki je uporabljen za enega ali več predmetov"; 
$LANG['setup'][64]="If you confirm the deletion the items using this heading used fields will be blanked"; 
$LANG['setup'][65]="Lahko pa tudi zamenjate vse dogodke naslova z drugim:"; 
$LANG['setup'][67]="Zunanja avtentikacija"; 
$LANG['setup'][69]="Tipi naprav"; 
$LANG['setup'][70]="Osnovna namestitev"; 
$LANG['setup'][71]="Firmware"; 
$LANG['setup'][73]="Mrežna točka"; 
$LANG['setup'][74]="Ne morete izbrisati tega področja zato ker vsebuje pod-področja"; 
$LANG['setup'][75]="Podrejeno"; 
$LANG['setup'][79]="Kategorije naročil"; 
$LANG['setup'][80]="Tretja stran tipov"; 
$LANG['setup'][81]="Naslovi dokumentov"; 
$LANG['setup'][82]="Tip kontakta"; 
$LANG['setup'][83]="Status predmeta"; 
$LANG['setup'][84]="Tip kartuše"; 
$LANG['setup'][85]="Tip pogodbe"; 
$LANG['setup'][86]="Type of memory"; 
$LANG['setup'][87]="Kategorije z bazami znanja"; 
$LANG['setup'][88]="Omrežje"; 
$LANG['setup'][89]="Domena"; 
$LANG['setup'][90]="VLANs"; 
$LANG['setup'][91]="Modeli računalnikov"; 
$LANG['setup'][92]="Tipi potrošnega materiala"; 
$LANG['setup'][93]="Vmesniki Trdih Diskov"; 
$LANG['setup'][94]="Modeli Monitorjev"; 
$LANG['setup'][95]="Modeli omrežij"; 
$LANG['setup'][96]="Tiskalniški modeli"; 
$LANG['setup'][97]="Modeli potrošnega materiala"; 
$LANG['setup'][98]="Naloge kategorij"; 
$LANG['setup'][99]="Gradnja številke"; 
$LANG['setup'][100]="Številka sobe"; 
$LANG['setup'][101]="Maksimalno število avtomatičnih dejanj (pognanih z CLI)"; 
$LANG['setup'][102]="Stopnja dnevnika (log)"; 
$LANG['setup'][103]="1- Kritično (zapiše samo napake)"; 
$LANG['setup'][104]="2- Strogo (Ne deluje)"; 
$LANG['setup'][105]="3- Pomembno (uspešne prijave)"; 
$LANG['setup'][106]="4- Zapiski (Dodano, zbrisano, sledenje)"; 
$LANG['setup'][107]="5- Kompletno (Vse)"; 
$LANG['setup'][109]="How long system logs are keep in database (in days, 0 for infinite)"; 
$LANG['setup'][110]="Prikaži nova naročila na uvodni strani"; 
$LANG['setup'][111]="Maximum number of search results to display on a page"; 
$LANG['setup'][112]="Maximum number of characters for each items in dropdowns"; 
$LANG['setup'][113]="Privzeti jezik"; 
$LANG['setup'][114]="Prioritetne barve"; 
$LANG['setup'][115]="Privzeta najvišja ali najnižja stopnja za kartuše in potrošno blago števec"; 
$LANG['setup'][116]="Avtomatsko dodeli naročilo odgovornemu tehniku"; 
$LANG['setup'][117]="Dovoli anomimen pogled FAQ-ja"; 
$LANG['setup'][118]="Tekst na prijavni strani"; 
$LANG['setup'][119]="Display"; 
$LANG['setup'][120]="Use dynamic display for dropdowns and text fields"; 
$LANG['setup'][121]="Character to force the full display of dropdowns (wildcard)"; 
$LANG['setup'][122]="Maximum number of items to display in the dropdowns when wildcard is not used"; 
$LANG['setup'][123]="Don't use dynamic display if the number of items is less than"; 
$LANG['setup'][124]="Avtomatično dodaj uporabnike iz zunanjega avtentikacijskega vira"; 
$LANG['setup'][125]="... Od zunanjega vira"; 
$LANG['setup'][126]="Avtomatsko dodaj uporabnika iz zunanjega vira"; 
$LANG['setup'][127]="Autocompletion of text fields"; 
$LANG['setup'][128]="Oblika datuma"; 
$LANG['setup'][129]="Show GLPI ID"; 
$LANG['setup'][130]="Število dni tega opravila so shranjena v dnevnik (log)"; 
$LANG['setup'][132]="Display the complete name in the tree dropdowns"; 
$LANG['setup'][133]="Aktiviraj OCSNG način"; 
$LANG['setup'][134]="OCSNG način"; 
$LANG['setup'][135]="Normalen"; 
$LANG['setup'][136]="Prevod"; 
$LANG['setup'][137]="Razhroščevanje"; 
$LANG['setup'][138]="Uporabi GLPI v načinu"; 
$LANG['setup'][139]="Pogosto"; 
$LANG['setup'][140]="Tipi"; 
$LANG['setup'][145]="Os"; 
$LANG['setup'][147]="Dynamic display"; 
$LANG['setup'][148]="Koraki za ure"; 
$LANG['setup'][149]="Število decimalk"; 
$LANG['setup'][150]="Oblika številke"; 
$LANG['setup'][154]="Osnovadn - basedn"; 
$LANG['setup'][155]="rootdn (za ne anonimne binde)"; 
$LANG['setup'][156]="Pass (za ne-anonimno bindanje - binds)"; 
$LANG['setup'][157]="LDAP dodatek za tvoj PHP razčlenjevalnik kode ni inštaliran"; 
$LANG['setup'][158]="Nemogoče je uporabiti LDAP kot zunanji vir povezave"; 
$LANG['setup'][159]="Filter povezave"; 
$LANG['setup'][162]="IMAP/POP konfiguracija"; 
$LANG['setup'][164]="IMAP/POP Host Name (uporabniški email bo: login@thishost)"; 
$LANG['setup'][165]="Tvoj PHP parser je bil skompajlan brez IMAP funkcij"; 
$LANG['setup'][166]="Nemogoče je uporabiti IMAP/POP kot zunanji vir povezave"; 
$LANG['setup'][167]="LDAP directory / GLPI links"; 
$LANG['setup'][168]="Možnosti povezave"; 
$LANG['setup'][169]="Email-prejeto (opcijsko, pogosto INBOX)"; 
$LANG['setup'][170]="Connection string"; 
$LANG['setup'][171]="Vrata (opcijsko)"; 
$LANG['setup'][172]="Port (default=389)"; 
$LANG['setup'][174]="CAS gostitelj"; 
$LANG['setup'][175]="Vrata"; 
$LANG['setup'][176]="Root imenik (opcijsko)"; 
$LANG['setup'][177]="CAS konfiguracija"; 
$LANG['setup'][178]="CURL ali DOMXML dodatek za PHP razhroščevalnik ni inštaliran"; 
$LANG['setup'][179]="Nemogoče je uporabiti CAS kota zunanji vir povezave"; 
$LANG['setup'][180]="Uporabite TLS"; 
$LANG['setup'][181]="ldap_start_tls ne obstaja"; 
$LANG['setup'][182]="Logout fallback URL"; 
$LANG['setup'][185]="Logs in files (SQL, email, automatic action...)"; 
$LANG['setup'][186]="Časovni pas"; 
$LANG['setup'][190]="x509 certifikat"; 
$LANG['setup'][191]="email atribut za x509"; 
$LANG['setup'][192]="Omogočeno"; 
$LANG['setup'][193]="Polje vsebuje prijavo v _SERVER polju"; 
$LANG['setup'][194]="Additional informations retrieval from LDAP directory"; 
$LANG['setup'][195]="Obdrži status"; 
$LANG['setup'][196]="Izbriši status"; 
$LANG['setup'][197]="Kopiraj status računalnika"; 
$LANG['setup'][198]="Nastavi status"; 
$LANG['setup'][199]="Odstrani domeno iz prijave v obrazcu login@domain"; 
$LANG['setup'][200]="Nedoločeno"; 
$LANG['setup'][201]="Alert and email followups configuration"; 
$LANG['setup'][202]="Enable Follow-up via email"; 
$LANG['setup'][203]="Administrator Pošte"; 
$LANG['setup'][204]="Email podpis"; 
$LANG['setup'][205]="Email poslan administratorju"; 
$LANG['setup'][206]="Napaka pri pošiljanju email-a administratorju"; 
$LANG['setup'][207]="Administratorjev odgovori na Email (če je potrebno)"; 
$LANG['setup'][217]="PHP mail funkcija je neznana ali pa ni aktivirana na vašem sistemu"; 
$LANG['setup'][218]="Potrebna je uporaba SMTP-ja"; 
$LANG['setup'][219]="Allow anonymous ticket creation (helpdesk.receiver)"; 
$LANG['setup'][221]="Beginning of fiscal year"; 
$LANG['setup'][223]="Omeji časovne razporejevalnike za planiranje"; 
$LANG['setup'][227]="URL of the application"; 
$LANG['setup'][228]="Prijavno polje"; 
$LANG['setup'][229]="Send a test email to the administrator"; 
$LANG['setup'][231]="Uporabite SMTP strežnik za pošiljanje pošte"; 
$LANG['setup'][232]="SMTP Host"; 
$LANG['setup'][234]="SMTP prijava"; 
$LANG['setup'][235]="SMTP Geslo"; 
$LANG['setup'][236]="Prešnji tehnik odogovoren za naročila"; 
$LANG['setup'][237]="Administrator"; 
$LANG['setup'][239]="Tehnik zadolžen za to naročilo"; 
$LANG['setup'][240]="Možnosti obveščanja"; 
$LANG['setup'][241]="Nobenih osebnih kriterijev. Naredim osebne parametre?"; 
$LANG['setup'][242]="Možnosti opozoril"; 
$LANG['setup'][243]="Alarm na potrošnem blagu - consumables."; 
$LANG['setup'][244]="Opozorila za kartuše"; 
$LANG['setup'][245]="Reminders frequency"; 
$LANG['setup'][246]="Opozorila na pogodbe"; 
$LANG['setup'][247]="Opozorila na finančne informacije"; 
$LANG['setup'][248]="Skupina odgovorna za naročila"; 
$LANG['setup'][249]="Prošnja za skupino"; 
$LANG['setup'][250]="Privzeti iskalni seznam"; 
$LANG['setup'][252]="Izberite privzeti predmet za prikaz"; 
$LANG['setup'][253]="Filtriraj za iskanje po skupinah"; 
$LANG['setup'][254]="Iskalni tip"; 
$LANG['setup'][255]="Skupine atributov, ki vsebujejo uporabnike"; 
$LANG['setup'][256]="V uporabnikih"; 
$LANG['setup'][257]="V skupinah"; 
$LANG['setup'][258]="Uporabniki & Skupine"; 
$LANG['setup'][259]="Pripada skupinam"; 
$LANG['setup'][260]="Uporabnikovi atributi vsebovani naslednjih skupinah"; 
$LANG['setup'][261]="Skupina DN"; 
$LANG['setup'][262]="Uporabite DN v iskanju"; 
$LANG['setup'][263]="Iskalni filter za uporabnike"; 
$LANG['setup'][264]="Opozorila na potekle licence"; 
$LANG['setup'][271]="Omejitev upravljanja z monitorji"; 
$LANG['setup'][272]="Omejitev upravljanja z napravami"; 
$LANG['setup'][273]="Omejitev upravljanja s telefoni"; 
$LANG['setup'][274]="Za ročno dodajanje"; 
$LANG['setup'][275]="Omejitev upravljanja s tiskalniki"; 
$LANG['setup'][280]="Automatically update of the elements related to the computers"; 
$LANG['setup'][281]="When connecting or updating"; 
$LANG['setup'][282]="When disconnecting"; 
$LANG['setup'][283]="Kopiraj"; 
$LANG['setup'][284]="Počisti"; 
$LANG['setup'][285]="Ne kopiraj"; 
$LANG['setup'][286]="Ne izbriši"; 
$LANG['setup'][300]="Preveri če je na voljo nova verzija"; 
$LANG['setup'][301]="Na voljo je nova verzija:"; 
$LANG['setup'][302]="Dosegljivo na GLPI strani: <a href='http://glpi-project' target='_blank'>http://glpi-project.org</a>"; 
$LANG['setup'][303]="Imate najnovejšo možno verzijo"; 
$LANG['setup'][304]="Povezava ni uspela. Če uporabljate proxy, ga prosim nastavite pravilno."; 
$LANG['setup'][305]="Vsak dan"; 
$LANG['setup'][306]="Preveri za posodobitev"; 
$LANG['setup'][307]="Nikoli"; 
$LANG['setup'][308]="Vsak teden"; 
$LANG['setup'][309]="Vsak mesec"; 
$LANG['setup'][310]="Ni se mogoče povezati na stran."; 
$LANG['setup'][311]="Napaka pri povezavi na proxy strežnik"; 
$LANG['setup'][312]="Na strani ni na voljo nobenih podatkov"; 
$LANG['setup'][313]="Bodi pozoren : ni privzete vrednosti"; 
$LANG['setup'][350]="Povezave na predmete za ustvarjanje naročil"; 
$LANG['setup'][351]="Vsi predmeti"; 
$LANG['setup'][352]="Povezljivi predmeti na naročila"; 
$LANG['setup'][360]="Avtomatična polja (označena z *)"; 
$LANG['setup'][400]="Konfiguracija proksija (proxy)"; 
$LANG['setup'][407]="Simplified interface help link"; 
$LANG['setup'][408]="Standard interface help link"; 
$LANG['setup'][409]="Privzeti naslov, ko dodaš dokument k naročilu"; 
$LANG['setup'][503]="Telefonski modeli"; 
$LANG['setup'][504]="Telefonski tipi"; 
$LANG['setup'][505]="Tipi napajalnikov za telefone"; 
$LANG['setup'][601]="LDAP vrednost"; 
$LANG['setup'][602]="Povezava na OSSNG bazo"; 
$LANG['setup'][603]="Dodaj uporabnika"; 
$LANG['setup'][604]="Asociraj na skupino"; 
$LANG['setup'][606]="Ni mogoče dodati. Uporabnik že obstaja."; 
$LANG['setup'][607]="Asociraj na profil"; 
$LANG['setup'][608]="Software associable to a ticket by default"; 
$LANG['setup'][609]="Unable to add. The OCSNG server already exists."; 
$LANG['setup'][610]="Obvezen naslov naročila"; 
$LANG['setup'][611]="Obvezna vsebina naročila"; 
$LANG['setup'][612]="Obvezna kategorija naročila"; 
$LANG['setup'][613]="Ddoaj uporabnika, ki nima pooblastila iz LDAP direktorija"; 
$LANG['setup'][614]="Nadgradnja prijave ni mogoča. Uporabnik že obstaja."; 
$LANG['setup'][615]="Življenski krog opravil"; 
$LANG['setup'][616]="Od \ Do"; 
$LANG['setup'][620]="Povezava"; 
$LANG['setup'][621]="Iskalni filter za entitete"; 
$LANG['setup'][622]="Atribut predstavljajoč entiteto"; 
$LANG['setup'][623]="Uvozi entite iz LDAP direktorija"; 
$LANG['setup'][650]="PHP"; 
$LANG['setup'][651]="SMTP"; 
$LANG['setup'][652]="SMTP+SSL"; 
$LANG['setup'][653]="SMTP+TLS"; 
$LANG['setup'][660]="Poštni strežnik"; 
$LANG['setup'][661]="Ne mogoče je konfigurirati prijave : prosim omogoči poštno nadzorovanje"; 
$LANG['setup'][703]="Splošno"; 
$LANG['setup'][704]="Obveščanja"; 
$LANG['setup'][707]="Alarmi na rezervacijah"; 
$LANG['setup'][708]="Alarmi na opravilih, ki niso rešeni od"; 
$LANG['setup'][720]="Sistemske informacije"; 
$LANG['setup'][721]="Informacije o sistemih inštalaciji in konfiguraciji"; 
$LANG['setup'][722]="Kopiraj/prilepi v tvojo prošnjo za podporo"; 
$LANG['setup'][731]="Vrednost globalne konfiguracije"; 
$LANG['setup'][732]="Domena za elektronsko poštno storitev"; 
$LANG['setup'][800]="Mysql repliciraj, podvoji"; 
$LANG['setup'][801]="Enable the MySQL replicate"; 
$LANG['setup'][802]="Baza"; 
$LANG['setup'][803]="Razlika med master in slave"; 
$LANG['setup'][806]="Max delay between master and slave (minutes)"; 
$LANG['setup'][807]="The slave base is desynchronized. The difference is of:"; 
$LANG['setup'][808]="Podovojena baza zunaj sinhronzacije!"; 
$LANG['setup'][809]="MySQL replika: le za branje"; 
$LANG['setup'][810]="Ne sinhronizacija MySQL replike"; 

$LANG['software'][1]="Nakup verzije"; 
$LANG['software'][2]="Uporabi verzijo"; 
$LANG['software'][3]="Ne inštalirane neprizadete licence"; 
$LANG['software'][4]="Neskončno"; 
$LANG['software'][5]="Verzije"; 
$LANG['software'][6]="Založnik"; 
$LANG['software'][7]="Dodaj verzijo"; 
$LANG['software'][8]="Dodaj licenco"; 
$LANG['software'][11]="Licence"; 
$LANG['software'][17]="Nameščena programska oprema"; 
$LANG['software'][19]="Namestitve"; 
$LANG['software'][20]="Preostalo"; 
$LANG['software'][28]="OEM"; 
$LANG['software'][29]="Posodobitev"; 
$LANG['software'][30]="Tipi licenc"; 
$LANG['software'][32]="Poteklo"; 
$LANG['software'][44]="Namesti programsko opremo"; 
$LANG['software'][45]="Izbriši programsko opremo"; 
$LANG['software'][46]="Associable to a ticket"; 
$LANG['software'][47]="Združevati"; 
$LANG['software'][48]="Združiti"; 
$LANG['software'][49]="Software, ki je dan v smeti po združevanju"; 
$LANG['software'][50]="Določen računalniku"; 
$LANG['software'][51]="Številka mora biti 1, da bo učinkovalo"; 

$LANG['softwarecategories'][2]="Uncategorized software"; 
$LANG['softwarecategories'][3]="Unfold the software without category"; 
$LANG['softwarecategories'][4]="Unfold the software belonging to a category"; 
$LANG['softwarecategories'][5]="Kategorija programske opreme"; 

$LANG['state'][0]="Status"; 
$LANG['state'][6]="Tip predmeta"; 
$LANG['state'][7]="Ni najdenih predmetov"; 
$LANG['state'][11]="Povzetek"; 

$LANG['stats'][0]="Izberi statistiko za prikaz"; 
$LANG['stats'][1]="Globalno"; 
$LANG['stats'][2]="Noben predmet ne bo viden"; 
$LANG['stats'][3]="Po napravi"; 
$LANG['stats'][5]="Number of opened tickets"; 
$LANG['stats'][6]="Povprečna resolucija zamika"; 
$LANG['stats'][7]="Prikaži grafiko"; 
$LANG['stats'][11]="Število rešenih naročil"; 
$LANG['stats'][13]="Število naročil"; 
$LANG['stats'][15]="Povprečna resolucija zamika"; 
$LANG['stats'][16]="Tehnik"; 
$LANG['stats'][20]="Uporabniško ime"; 
$LANG['stats'][23]="Nobena statistika ni na voljo"; 
$LANG['stats'][25]="Povprečno trajanje zahtveka"; 
$LANG['stats'][27]="Skupno trajanje naročila"; 
$LANG['stats'][30]="Povprečni zamik odziva na naročilo"; 
$LANG['stats'][31]="Dan"; 
$LANG['stats'][33]="Minute"; 
$LANG['stats'][34]="Sekunde"; 
$LANG['stats'][35]="naročilo(a)"; 
$LANG['stats'][44]="Ime dobavitelja"; 
$LANG['stats'][45]="Po programski opremi"; 
$LANG['stats'][47]="Po naročilu"; 
$LANG['stats'][48]="(dodeljen)"; 
$LANG['stats'][49]="(sledi-zgoraj)(follow-ups)"; 

$LANG['title'][5]="Baza znanja"; 
$LANG['title'][6]="Mreženje"; 
$LANG['title'][9]="Status predmeta"; 
$LANG['title'][10]="Odgovor Naročila"; 
$LANG['title'][13]="Informacije o uporabniku"; 
$LANG['title'][14]="Zunanji avtentikacijski viri"; 
$LANG['title'][24]="Pomoč"; 
$LANG['title'][26]="Glavno"; 
$LANG['title'][27]="Povezave"; 
$LANG['title'][28]="Naročila"; 
$LANG['title'][30]="Komponente"; 
$LANG['title'][33]="Zunanje povezave"; 
$LANG['title'][34]="Linki"; 
$LANG['title'][37]="Zapiski"; 
$LANG['title'][38]="Zgodovinsko"; 
$LANG['title'][40]="Javni in osebni zapiski"; 
$LANG['title'][42]="Velike spremembe"; 
$LANG['title'][43]="Register"; 

$LANG['tracking'][1]="Moje naprave"; 
$LANG['tracking'][2]="Ali zaključi iskanje"; 
$LANG['tracking'][3]="Nepravilni datumi. Posodobitev je bila preklicana."; 
$LANG['tracking'][4]="Ni nobene nuje za privzeto opravilo, prosim popravi."; 
$LANG['tracking'][8]="Ni opisa za vaše naročilo, poizkusite ponovno"; 
$LANG['tracking'][9]="Privzeto za sprejeto opravilo"; 
$LANG['tracking'][10]="Privzeto za sprejemnike elektronske pošte"; 
$LANG['tracking'][24]="Dokument Opravila"; 
$LANG['tracking'][29]="Število"; 
$LANG['tracking'][30]="Nov"; 
$LANG['tracking'][31]="V teku (dodeljeno)"; 
$LANG['tracking'][32]="V teku (načrtovano)"; 
$LANG['tracking'][34]="Osebno"; 
$LANG['tracking'][35]="Pisno"; 
$LANG['tracking'][37]="Ohrani opravila ob dokončnem brisanju (purge) strojne opreme iz seznamov"; 
$LANG['tracking'][38]="Email je bil poslan k"; 
$LANG['tracking'][39]="Videno v enostavnem vmesniku."; 

$LANG['transfer'][1]="Prenos"; 
$LANG['transfer'][3]="če ni uporabljeno"; 
$LANG['transfer'][4]="S prazni seznam elementov, kateri naj bodo prenešeni"; 
$LANG['transfer'][5]="Lahko nadaljuješ, da dodaš elemente, da so preneseni ali prenesi od sedaj te elemente"; 
$LANG['transfer'][6]="Razmisli o varnostnih kopijah preden prenašaš predmete."; 
$LANG['transfer'][7]="Predmeti za prenos"; 
$LANG['transfer'][8]="Način prenosa"; 

$LANG['update'][88]="Vaša verzija baze ni kompatibilna z nameščeno kodo. Potrebna je posodobitev."; 
$LANG['update'][89]="Poizkušate uporabiti GLPI z bazo, ki je načrtovana za novejše verzije. Prosim namestite verzijo, ki korenspondira vaši bazi."; 
$LANG['update'][90]="Napaka pri posodabljanju baze"; 
$LANG['update'][91]="Previdno!"; 
$LANG['update'][92]="Posodobili boste GLPI bazo z imenom :"; 
$LANG['update'][93]="Priklop na bazo uspešen"; 
$LANG['update'][94]="Posodobitev uspešna, vaša baza je posodobljena na najnovejšo verzijo"; 
$LANG['update'][95]="Povezava z bazo ni uspešna, preverite povezovalne parametre v config_db.php datoteki"; 
$LANG['update'][96]="Zdaj imajo vsi administratorji 'super-admin' pravice. Ta nov tip uporabnika je bil prav tako dodan."; 
$LANG['update'][105]="Nemogoče je dokončati posodobitev na ta način!!"; 
$LANG['update'][106]="Pojdi nazaj na GLPI"; 
$LANG['update'][107]="Zdaj morate nadaljevati k posodobitvi vsebine baze"; 
$LANG['update'][130]="Posodobitev lokacij"; 
$LANG['update'][131]="Nova struktura je hierarhična"; 
$LANG['update'][132]="Če si rabil znak za razmejitev, lahko določiš v zaporedju, da avtomatizeraš generacijo hierarhij."; 
$LANG['update'][133]="Definirate lahko root lokacijo, ki bo vsebovala vse generirane lokacije."; 
$LANG['update'][134]="Razmejitveni znak"; 
$LANG['update'][135]="Root lokacija"; 
$LANG['update'][136]="To je nova hierarhija. Če je pravilna jo lahko preverite."; 
$LANG['update'][137]="Nova hierarhija"; 
$LANG['update'][138]="Dejanske lokacije"; 
$LANG['update'][139]="Optimizacija tabel"; 
$LANG['update'][140]="Kreiranje indeksov"; 
$LANG['update'][141]="Sprememba podatkovne baze njene sheme"; 
$LANG['update'][142]="Migracija podatkov"; 

$LANG['users'][1]="Naziv"; 
$LANG['users'][2]="Kategorija"; 

$LANG['validation'][0]="Uzakonitev"; 
$LANG['validation'][1]="Pošlji prošnjo za uzakonitev"; 
$LANG['validation'][2]="Stanje"; 
$LANG['validation'][3]="Zaprosi datum"; 
$LANG['validation'][4]="Datum uzakonitve"; 
$LANG['validation'][5]="Pojasniti prošnjo"; 
$LANG['validation'][6]="Prošnjo ovrednotiti"; 
$LANG['validation'][7]="Potrditev, uzakonitev opravila"; 
$LANG['validation'][9]="Čakajoč na legalizacijo, uzakonitev opravila"; 
$LANG['validation'][10]="Zavrnjen"; 
$LANG['validation'][11]="Sprejeto"; 
$LANG['validation'][12]="Not subject to approval"; 
$LANG['validation'][13]="Prošnja za uzakonitev poslana"; 
$LANG['validation'][15]="Opravila čakajo na tvojo potrditev"; 
$LANG['validation'][16]="Neobvezno, če bo sprejet"; 
$LANG['validation'][18]="Zahtevana se uzakonitev"; 
$LANG['validation'][19]="Uzakonitev sprejeta"; 
$LANG['validation'][20]="Uzakonitev zavrnjena"; 
$LANG['validation'][21]="Uzakonitev, potrditev uporabnika"; 
$LANG['validation'][23]="Izbrani uporabnik nima veljavnega e-poštnega naslova. Prošnja se je skreirala, toda ni bila poslana na noben e-poštni naslov."; 
$LANG['validation'][26]="Prošnja za uzakonitev"; 
$LANG['validation'][27]="Prošnja za vrednotenje je bila predložena"; 
$LANG['validation'][28]="Stanje prošnje za uzakonitev"; 
$LANG['validation'][29]="Če se ne strinjaš, moraš podrobno navesti razloge"; 
$LANG['validation'][30]="Odstrani prošnjo za veljavnost do"; 
$LANG['validation'][31]="Posodobi veljavno prošnjo"; 
$LANG['validation'][32]="Odgovor na prošnjo za vrednotenje se je izvršil."; 
$LANG['validation'][33]="Opravila čakajo na tvojo odobritev"; 
?>